// ==================================
// Global CSS for 'sap_fiori_3' theme
// ==================================

// =====================================
// Semantic Theming Mapping
// =====================================

// ==========================================================
// Quick Theming (these Parameters can be linked in controls)
// ==========================================================

@sapUiBrand: @sapBrandColor;
@sapUiHighlight: @sapHighlightColor;
@sapUiBaseColor: @sapBaseColor;
@sapUiShellColor: @sapShellColor;
@sapUiBaseBG: @sapBackgroundColor;
@sapUiGlobalBackgroundColor: @sapBackgroundColor;
@sapUiFontFamily: @sapFontFamily;
@sapUiFontSize: 16px; // @sapFontSize;
@sapUiBaseText: @sapTextColor;
@sapUiLink: @sapLinkColor;
@sapUiGlobalLogo: @sapCompanyLogo;
@sapUiFavicon: @sapFavicon;
@sapUiGlobalBackgroundImage: @sapBackgroundImage;
@sapUiBackgroundImage: @sapBackgroundImage;
@sapUiUx3ShellBackgroundImageURL: @sapBackgroundImage;
@sapUiGlobalBackgroundImageOpacity: @sapBackgroundImageOpacity;
@sapUiGlobalBackgroundRepeat: @sapBackgroundImageRepeat;
@sapUiSelected: @sapSelectedColor;
@sapUiHover: @sapHoverColor;
@sapUiActive: @sapActiveColor;
@sapUiHighlightTextColor: @sapHighlightTextColor;
@sapUiTextTitle: @sapTitleColor;


// =======================================================
// Semantic Foreground Colors - do not use in Controls!!
// =======================================================

@sapUiNegative: @sapNegativeColor;
@sapUiCritical: @sapCriticalColor;
@sapUiPositive: @sapPositiveColor;
@sapUiInformative: @sapInformativeColor;
@sapUiNeutral: @sapNeutralColor;


// =====================================
// Semantic Colors
// =====================================

// Semantic Foreground Elements

@sapUiNegativeElement: @sapNegativeElementColor;
@sapUiCriticalElement: @sapCriticalElementColor;
@sapUiPositiveElement: @sapPositiveElementColor;
@sapUiInformativeElement: @sapInformativeElementColor;
@sapUiNeutralElement: @sapNeutralElementColor;


// Semantic Text

@sapUiNegativeText: @sapNegativeTextColor;
@sapUiCriticalText: @sapCriticalTextColor;
@sapUiPositiveText: @sapPositiveTextColor;
@sapUiInformativeText: @sapInformativeTextColor;
@sapUiNeutralText: @sapNeutralTextColor;


// Semantic Background Colors

@sapUiErrorBG: @sapErrorBackground;
@sapUiWarningBG: @sapWarningBackground;
@sapUiSuccessBG: @sapSuccessBackground;
@sapUiInformationBG: @sapInformationBackground;
@sapUiNeutralBG: @sapNeutralBackground;


// Semantic Border Colors

@sapUiErrorBorder: @sapErrorBorderColor;
@sapUiWarningBorder: @sapWarningBorderColor;
@sapUiSuccessBorder: @sapSuccessBorderColor;
@sapUiInformationBorder: @sapInformationBorderColor;
@sapUiNeutralBorder: @sapNeutralBorderColor;


// ==============================================================
// Expert Theming (these Parameters should be linked in controls)
// ==============================================================

@sapUiElementLineHeight: @sapElement_LineHeight;
@sapUiElementHeight: @sapElement_Height;
@sapUiElementBorderWidth: @sapElement_BorderWidth;
@sapUiElementBorderCornerRadius: @sapElement_BorderCornerRadius;
@sapUiElementCompactLineHeight: @sapElement_Compact_LineHeight;
@sapUiElementCompactHeight: @sapElement_Compact_Height;
@sapUiElementCondensedLineHeight: @sapElement_Condensed_LineHeight;
@sapUiElementCondensedHeight: @sapElement_Condensed_Height;

@sapUiContentLineHeight: @sapContent_LineHeight;
@sapUiContentIconHeight: @sapContent_IconHeight;
@sapUiContentIconColor: @sapContent_IconColor;
@sapUiContentContrastIconColor: @sapContent_ContrastIconColor;
@sapUiContentNonInteractiveIconColor: @sapContent_NonInteractiveIconColor;
@sapUiContentMarkerIconColor: @sapContent_MarkerIconColor;
@sapUiContentMarkerTextColor: @sapContent_MarkerTextColor;
@sapUiContentMeasureIndicatorColor: @sapContent_MeasureIndicatorColor;
@sapUiContentSelectedMeasureIndicatorColor: @sapContent_Selected_MeasureIndicatorColor;
@sapUiContentPlaceholderloadingBackground: @sapContent_Placeholderloading_Background;
@sapUiContentPlaceholderloadingGradient: @sapContent_Placeholderloading_Gradient;
@sapUiContentImagePlaceholderBackground: @sapContent_ImagePlaceholderBackground;
@sapUiContentImagePlaceholderForegroundColor: @sapContent_ImagePlaceholderForegroundColor;
@sapUiContentRatedColor: @sapContent_RatedColor;
@sapUiContentUnratedColor: @sapContent_UnratedColor;
@sapUiContentBusyColor: @sapContent_BusyColor;
@sapUiContentFocusColor: @sapContent_FocusColor;
@sapUiContentFocusStyle: @sapContent_FocusStyle;
@sapUiContentFocusWidth: @sapContent_FocusWidth;
@sapUiContentContrastFocusColor: @sapContent_ContrastFocusColor;
@sapUiContentShadowColor: @sapContent_ShadowColor;
@sapUiContentContrastShadowColor: @sapContent_ContrastShadowColor;
@sapUiContentShadow0: @sapContent_Shadow0;
@sapUiContentShadow1: @sapContent_Shadow1;
@sapUiContentShadow2: @sapContent_Shadow2;
@sapUiContentShadow3: @sapContent_Shadow3;
@sapUiContentTextShadow: @sapContent_TextShadow;
@sapUiContentContrastTextShadow: @sapContent_ContrastTextShadow;
@sapUiContentHeaderShadow: @sapContent_HeaderShadow;
@sapUiContentInteractionShadow: @sapContent_Interaction_Shadow;
@sapUiContentSelectedShadow: @sapContent_Selected_Shadow;
@sapUiContentNegativeShadow: @sapContent_Negative_Shadow;
@sapUiContentCriticalShadow: @sapContent_Critical_Shadow;
@sapUiContentPositiveShadow: @sapContent_Positive_Shadow;
@sapUiContentInformativeShadow: @sapContent_Informative_Shadow;
@sapUiContentNeutralShadow: @sapContent_Neutral_Shadow;
@sapUiContentSearchHighlightColor: @sapContent_SearchHighlightColor;
@sapUiContentHelpColor: @sapContent_HelpColor;
@sapUiContentLabelColor: @sapContent_LabelColor;
@sapUiContentMonospaceFontFamily: @sapContent_MonospaceFontFamily;
@sapUiContentMonospaceBoldFontFamily: @sapContent_MonospaceBoldFontFamily;
@sapUiContentIconFontFamily: @sapContent_IconFontFamily;
@sapUiContentDisabledTextColor: @sapContent_DisabledTextColor;
@sapUiContentDisabledOpacity: @sapContent_DisabledOpacity;
@sapUiContentContrastTextThreshold: @sapContent_ContrastTextThreshold;
@sapUiContentContrastTextColor: @sapContent_ContrastTextColor;
@sapUiContentForegroundColor: @sapContent_ForegroundColor;
@sapUiContentForegroundBorderColor: @sapContent_ForegroundBorderColor;
@sapUiContentForegroundTextColor: @sapContent_ForegroundTextColor;
@sapUiContentBadgeBackground: @sapContent_BadgeBackground;
@sapUiContentBadgeTextColor: @sapContent_BadgeTextColor;
@sapUiContentBadgeBorderColor: @sapContent_BadgeBorderColor;
@sapUiContentDragAndDropActiveColor: @sapContent_DragAndDropActiveColor;
@sapUiContentSelectedTextColor: @sapContent_Selected_TextColor;
@sapUiContentSelectedBackground: @sapContent_Selected_Background;
@sapUiContentSelectedHoverBackground: @sapContent_Selected_Hover_Background;
@sapUiContentSelectedForegroundColor: @sapContent_Selected_ForegroundColor;
@sapUiContentForcedColorAdjust: @sapContent_ForcedColorAdjust;
@sapUiContentLiteShadow: @sapContent_Lite_Shadow;

@sapUiContentIllustrativeColor1: @sapContent_Illustrative_Color1;
@sapUiContentIllustrativeColor2: @sapContent_Illustrative_Color2;
@sapUiContentIllustrativeColor3: @sapContent_Illustrative_Color3;
@sapUiContentIllustrativeColor4: @sapContent_Illustrative_Color4;
@sapUiContentIllustrativeColor5: @sapContent_Illustrative_Color5;
@sapUiContentIllustrativeColor6: @sapContent_Illustrative_Color6;
@sapUiContentIllustrativeColor7: @sapContent_Illustrative_Color7;
@sapUiContentIllustrativeColor8: @sapContent_Illustrative_Color8;
@sapUiContentIllustrativeColor9: @sapContent_Illustrative_Color9;
@sapUiContentIllustrativeColor10: @sapContent_Illustrative_Color10;
@sapUiContentIllustrativeColor11: @sapContent_Illustrative_Color11;
@sapUiContentIllustrativeColor12: @sapContent_Illustrative_Color12;
@sapUiContentIllustrativeColor13: @sapContent_Illustrative_Color13;
@sapUiContentIllustrativeColor14: @sapContent_Illustrative_Color14;
@sapUiContentIllustrativeColor15: @sapContent_Illustrative_Color15;
@sapUiContentIllustrativeColor16: @sapContent_Illustrative_Color16;
@sapUiContentIllustrativeColor17: @sapContent_Illustrative_Color17;
@sapUiContentIllustrativeColor18: @sapContent_Illustrative_Color18;
@sapUiContentIllustrativeColor19: @sapContent_Illustrative_Color19;
@sapUiContentIllustrativeColor20: @sapContent_Illustrative_Color20;
@sapUiContentIllustrativeColor21: @sapContent_Illustrative_Color21;
@sapUiContentIllustrativeColor22: @sapContent_Illustrative_Color22;
@sapUiContentIllustrativeColor23: @sapContent_Illustrative_Color23;
@sapUiContentIllustrativeColor24: @sapContent_Illustrative_Color24;
@sapUiContentIllustrativeColor25: @sapContent_Illustrative_Color25;
@sapUiContentIllustrativeColor26: @sapContent_Illustrative_Color26;
@sapUiContentIllustrativeColor27: @sapContent_Illustrative_Color27;
@sapUiContentIllustrativeColor28: @sapContent_Illustrative_Color28;
@sapUiContentIllustrativeColor29: @sapContent_Illustrative_Color29;
@sapUiContentIllustrativeColor30: @sapContent_Illustrative_Color30;
@sapUiContentIllustrativeColor31: @sapContent_Illustrative_Color31;

@sapUiContentSpaceS: @sapContent_Space_S;
@sapUiContentSpaceM: @sapContent_Space_M;
@sapUiContentSpaceL: @sapContent_Space_L;
@sapUiContentSpaceXL: @sapContent_Space_XL;
@sapUiContentSpaceTiny: @sapContent_Space_Tiny;
@sapUiContentSpaceSmall: @sapContent_Space_Small;
@sapUiContentSpaceMedium: @sapContent_Space_Medium;
@sapUiContentSpaceLarge: @sapContent_Space_Large;
@sapUiContentMarginTiny: @sapContent_Margin_Tiny;
@sapUiContentMarginSmall: @sapContent_Margin_Small;
@sapUiContentMarginMedium: @sapContent_Margin_Medium;
@sapUiContentMarginLarge: @sapContent_Margin_Large;
@sapUiContentGap: @sapContent_Gap;
@sapUiContentPaddingS: @sapContent_Padding_S;
@sapUiContentPaddingM: @sapContent_Padding_M;
@sapUiContentPaddingL: @sapContent_Padding_L;
@sapUiContentPaddingXL: @sapContent_Padding_XL;
@sapUiContentSuccessHeaderShadow: @sapContent_Success_HeaderShadow;
@sapUiContentWarningHeaderShadow: @sapContent_Warning_HeaderShadow;
@sapUiContentErrorHeaderShadow: @sapContent_Error_HeaderShadow;
@sapUiContentInformationHeaderShadow: @sapContent_Information_HeaderShadow;

@sapUiFontLightFamily: @sapFontLightFamily;
@sapUiFontBoldFamily: @sapFontBoldFamily;
@sapUiFontSemiboldFamily: @sapFontSemiboldFamily;
@sapUiFontSemiboldDuplexFamily: @sapFontSemiboldDuplexFamily;
@sapUiFontBlackFamily: @sapFontBlackFamily;
@sapUiFontHeaderFamily: @sapFontHeaderFamily;
@sapMFontSmallSize: @sapFontSmallSize;
@sapMFontLargeSize: @sapFontLargeSize;
@sapMFontHeader1Size: @sapFontHeader1Size;
@sapMFontHeader2Size: @sapFontHeader2Size;
@sapMFontHeader3Size: @sapFontHeader3Size;
@sapMFontHeader4Size: @sapFontHeader4Size;
@sapMFontHeader5Size: @sapFontHeader5Size;
@sapMFontHeader6Size: @sapFontHeader6Size;

@sapUiLinkTextDecoration: @sapLink_TextDecoration;
@sapUiLinkHoverColor: @sapLink_Hover_Color;
@sapUiLinkHoverTextDecoration: @sapLink_Hover_TextDecoration;
@sapUiLinkActiveColor: @sapLink_Active_Color;
@sapUiLinkActiveTextDecoration: @sapLink_Active_TextDecoration;
@sapUiLinkVisitedColor: @sapLink_Visited_Color;
@sapUiLinkInvertedColor: @sapLink_InvertedColor;
@sapUiLinkSubtleColor: @sapLink_SubtleColor;

@sapUiShellBackground: @sapShell_Background;
@sapUiShellBackgroundImage: @sapShell_BackgroundImage;
@sapUiShellBackgroundImageOpacity: @sapShell_BackgroundImageOpacity;
@sapUiShellBackgroundImageRepeat: @sapShell_BackgroundImageRepeat;
@sapUiShellBorderColor: @sapShell_BorderColor;
@sapUiShellTextColor: @sapShell_TextColor;
@sapUiShellInteractiveBackground: @sapShell_InteractiveBackground;
@sapUiShellInteractiveTextColor: @sapShell_InteractiveTextColor;
@sapUiShellInteractiveBorderColor: @sapShell_InteractiveBorderColor;
@sapUiShellGroupTitleTextColor: @sapShell_GroupTitleTextColor;
@sapUiShellGroupTitleTextShadow: @sapShell_GroupTitleTextShadow;
@sapUiShellHoverBackground: @sapShell_Hover_Background;
@sapUiShellActiveBackground: @sapShell_Active_Background;
@sapUiShellActiveTextColor: @sapShell_Active_TextColor;
@sapUiShellSelectedBackground: @sapShell_Selected_Background;
@sapUiShellSelectedTextColor: @sapShell_Selected_TextColor;
@sapUiShellSelectedHoverBackground: @sapShell_Selected_Hover_Background;
@sapUiShellFavicon: @sapShell_Favicon;
@sapUiShellNavigationBackground: @sapShell_Navigation_Background;
@sapUiShellNavigationHoverBackground: @sapShell_Navigation_Hover_Background;
@sapUiShellNavigationSelectedColor: @sapShell_Navigation_SelectedColor;
@sapUiShellNavigationSelectedTextColor: @sapShell_Navigation_Selected_TextColor;
@sapUiShellNavigationTextColor: @sapShell_Navigation_TextColor;
@sapUiShellNavigationActiveTextColor: @sapShell_Navigation_Active_TextColor;
@sapUiShellNavigationActiveBackground: @sapShell_Navigation_Active_Background;
@sapUiShellShadow: @sapShell_Shadow;
@sapUiShellNegativeColor: @sapShell_NegativeColor;
@sapUiShellCriticalColor: @sapShell_CriticalColor;
@sapUiShellPositiveColor: @sapShell_PositiveColor;
@sapUiShellInformativeColor: @sapShell_InformativeColor;
@sapUiShellNeutralColor: @sapShell_NeutralColor;
@sapUiShellAssistantForegroundColor: @sapShell_Assistant_ForegroundColor;
@sapUiShellSubBrandTextColor: @sapShell_SubBrand_TextColor;
@sapUiShellCategory1Background: @sapShell_Category_1_Background;
@sapUiShellCategory1BorderColor: @sapShell_Category_1_BorderColor;
@sapUiShellCategory1TextColor: @sapShell_Category_1_TextColor;
@sapUiShellCategory1TextShadow: @sapShell_Category_1_TextShadow;
@sapUiShellCategory2Background: @sapShell_Category_2_Background;
@sapUiShellCategory2BorderColor: @sapShell_Category_2_BorderColor;
@sapUiShellCategory2TextColor: @sapShell_Category_2_TextColor;
@sapUiShellCategory2TextShadow: @sapShell_Category_2_TextShadow;
@sapUiShellCategory31Background: @sapShell_Category_3_Background;
@sapUiShellCategory3BorderColor: @sapShell_Category_3_BorderColor;
@sapUiShellCategory3TextColor: @sapShell_Category_3_TextColor;
@sapUiShellCategory3TextShadow: @sapShell_Category_3_TextShadow;
@sapUiShellCategory4Background: @sapShell_Category_4_Background;
@sapUiShellCategory4BorderColor: @sapShell_Category_4_BorderColor;
@sapUiShellCategory4TextColor: @sapShell_Category_4_TextColor;
@sapUiShellCategory4TextShadow: @sapShell_Category_4_TextShadow;
@sapUiShellCategory5Background: @sapShell_Category_5_Background;
@sapUiShellCategory5BorderColor: @sapShell_Category_5_BorderColor;
@sapUiShellCategory5TextColor: @sapShell_Category_5_TextColor;
@sapUiShellCategory5TextShadow: @sapShell_Category_5_TextShadow;
@sapUiShellCategory6Background: @sapShell_Category_6_Background;
@sapUiShellCategory6BorderColor: @sapShell_Category_6_BorderColor;
@sapUiShellCategory6TextColor: @sapShell_Category_6_TextColor;
@sapUiShellCategory6TextShadow: @sapShell_Category_6_TextShadow;
@sapUiShellCategory7Background: @sapShell_Category_7_Background;
@sapUiShellCategory7BorderColor: @sapShell_Category_7_BorderColor;
@sapUiShellCategory7TextColor: @sapShell_Category_7_TextColor;
@sapUiShellCategory7TextShadow: @sapShell_Category_7_TextShadow;
@sapUiShellCategory8Background: @sapShell_Category_8_Background;
@sapUiShellCategory8BorderColor: @sapShell_Category_8_BorderColor;
@sapUiShellCategory8TextColor: @sapShell_Category_8_TextColor;
@sapUiShellCategory8TextShadow: @sapShell_Category_8_TextShadow;
@sapUiShellCategory9Background: @sapShell_Category_9_Background;
@sapUiShellCategory9BorderColor: @sapShell_Category_9_BorderColor;
@sapUiShellCategory9TextColor: @sapShell_Category_9_TextColor;
@sapUiShellCategory9TextShadow: @sapShell_Category_9_TextShadow;
@sapUiShellCategory10Background: @sapShell_Category_10_Background;
@sapUiShellCategory10BorderColor: @sapShell_Category_10_BorderColor;
@sapUiShellCategory10TextColor: @sapShell_Category_10_TextColor;
@sapUiShellCategory10TextShadow: @sapShell_Category_10_TextShadow;
@sapUiShellCategory11Background: @sapShell_Category_11_Background;
@sapUiShellCategory11BorderColor: @sapShell_Category_11_BorderColor;
@sapUiShellCategory11TextColor: @sapShell_Category_11_TextColor;
@sapUiShellCategory11TextShadow: @sapShell_Category_11_TextShadow;
@sapUiShellCategory12Background: @sapShell_Category_12_Background;
@sapUiShellCategory12BorderColor: @sapShell_Category_12_BorderColor;
@sapUiShellCategory12TextColor: @sapShell_Category_12_TextColor;
@sapUiShellCategory12TextShadow: @sapShell_Category_12_TextShadow;
@sapUiShellCategory13Background: @sapShell_Category_13_Background;
@sapUiShellCategory13BorderColor: @sapShell_Category_13_BorderColor;
@sapUiShellCategory13TextColor: @sapShell_Category_13_TextColor;
@sapUiShellCategory13TextShadow: @sapShell_Category_13_TextShadow;
@sapUiShellCategory14Background: @sapShell_Category_14_Background;
@sapUiShellCategory14BorderColor: @sapShell_Category_14_BorderColor;
@sapUiShellCategory14TextColor: @sapShell_Category_14_TextColor;
@sapUiShellCategory14TextShadow: @sapShell_Category_14_TextShadow;
@sapUiShellCategory15Background: @sapShell_Category_15_Background;
@sapUiShellCategory15BorderColor: @sapShell_Category_15_BorderColor;
@sapUiShellCategory15TextColor: @sapShell_Category_15_TextColor;
@sapUiShellCategory15TextShadow: @sapShell_Category_15_TextShadow;
@sapUiShellCategory16Background: @sapShell_Category_16_Background;
@sapUiShellCategory16BorderColor: @sapShell_Category_16_BorderColor;
@sapUiShellCategory16TextColor: @sapShell_Category_16_TextColor;
@sapUiShellCategory16TextShadow: @sapShell_Category_16_TextShadow;
@sapUiShellSpaceS: @sapShell_Space_S;
@sapUiShellSpaceM: @sapShell_Space_M;
@sapUiShellSpaceL: @sapShell_Space_L;
@sapUiShellSpaceXL: @sapShell_Space_XL;
@sapUiShellGapS: @sapShell_Gap_S;
@sapUiShellGapM: @sapShell_Gap_M;
@sapUiShellGapL: @sapShell_Gap_L;
@sapUiShellGapXL: @sapShell_Gap_XL;
@sapUiShellGroupGapS: @sapShell_GroupGap_S;
@sapUiShellGroupGapM: @sapShell_GroupGap_M;
@sapUiShellGroupGapL: @sapShell_GroupGap_L;
@sapUiShellGroupGapXL: @sapShell_GroupGap_XL;

@sapUiAssistantColor1: @sapAssistant_Color1;
@sapUiAssistantColor2: @sapAssistant_Color2;
@sapUiAssistantBackgroundGradient: @sapAssistant_BackgroundGradient;
@sapUiAssistantBackground: @sapAssistant_Background;
@sapUiAssistantBorderColor: @sapAssistant_BorderColor;
@sapUiAssistantTextColor: @sapAssistant_TextColor;
@sapUiAssistantHoverBackground: @sapAssistant_Hover_Background;
@sapUiAssistantHoverBorderColor: @sapAssistant_Hover_BorderColor;
@sapUiAssistantHoverTextColor: @sapAssistant_Hover_TextColor;
@sapUiAssistantActiveBackground: @sapAssistant_Active_Background;
@sapUiAssistantActiveBorderColor: @sapAssistant_Active_BorderColor;
@sapUiAssistantActiveTextColor: @sapAssistant_Active_TextColor;
@sapUiAssistantQuestionBackground: @sapAssistant_Question_Background;
@sapUiAssistantQuestionBorderColor: @sapAssistant_Question_BorderColor;
@sapUiAssistantQuestionTextColor: @sapAssistant_Question_TextColor;
@sapUiAssistantAnswerBackground: @sapAssistant_Answer_Background;
@sapUiAssistantAnswerBorderColor: @sapAssistant_Answer_BorderColor;
@sapUiAssistantAnswerTextColor: @sapAssistant_Answer_TextColor;

@sapUiAvatar1Background: @sapAvatar_1_Background;
@sapUiAvatar1BorderColor: @sapAvatar_1_BorderColor;
@sapUiAvatar1TextColor: @sapAvatar_1_TextColor;
@sapUiAvatar1HoverBackground: @sapAvatar_1_Hover_Background;
@sapUiAvatar2Background: @sapAvatar_2_Background;
@sapUiAvatar2BorderColor: @sapAvatar_2_BorderColor;
@sapUiAvatar2TextColor: @sapAvatar_2_TextColor;
@sapUiAvatar2HoverBackground: @sapAvatar_2_Hover_Background;
@sapUiAvatar3Background: @sapAvatar_3_Background;
@sapUiAvatar3BorderColor: @sapAvatar_3_BorderColor;
@sapUiAvatar3TextColor: @sapAvatar_3_TextColor;
@sapUiAvatar3HoverBackground: @sapAvatar_3_Hover_Background;
@sapUiAvatar4Background: @sapAvatar_4_Background;
@sapUiAvatar4BorderColor: @sapAvatar_4_BorderColor;
@sapUiAvatar4TextColor: @sapAvatar_4_TextColor;
@sapUiAvatar4HoverBackground: @sapAvatar_4_Hover_Background;
@sapUiAvatar5Background: @sapAvatar_5_Background;
@sapUiAvatar5BorderColor: @sapAvatar_5_BorderColor;
@sapUiAvatar5TextColor: @sapAvatar_5_TextColor;
@sapUiAvatar5HoverBackground: @sapAvatar_5_Hover_Background;
@sapUiAvatar6Background: @sapAvatar_6_Background;
@sapUiAvatar6BorderColor: @sapAvatar_6_BorderColor;
@sapUiAvatar6TextColor: @sapAvatar_6_TextColor;
@sapUiAvatar6HoverBackground: @sapAvatar_6_Hover_Background;
@sapUiAvatar7Background: @sapAvatar_7_Background;
@sapUiAvatar7BorderColor: @sapAvatar_7_BorderColor;
@sapUiAvatar7TextColor: @sapAvatar_7_TextColor;
@sapUiAvatar7HoverBackground: @sapAvatar_7_Hover_Background;
@sapUiAvatar8Background: @sapAvatar_8_Background;
@sapUiAvatar8BorderColor: @sapAvatar_8_BorderColor;
@sapUiAvatar8TextColor: @sapAvatar_8_TextColor;
@sapUiAvatar8HoverBackground: @sapAvatar_8_Hover_Background;
@sapUiAvatar9Background: @sapAvatar_9_Background;
@sapUiAvatar9BorderColor: @sapAvatar_9_BorderColor;
@sapUiAvatar9TextColor: @sapAvatar_9_TextColor;
@sapUiAvatar9HoverBackground: @sapAvatar_9_Hover_Background;
@sapUiAvatar10Background: @sapAvatar_10_Background;
@sapUiAvatar10BorderColor: @sapAvatar_10_BorderColor;
@sapUiAvatar10TextColor: @sapAvatar_10_TextColor;
@sapUiAvatar10HoverBackground: @sapAvatar_10_Hover_Background;
@sapUiAvatarLiteBorderColor: @sapAvatar_Lite_BorderColor;
@sapUiAvatarLiteBackground: @sapAvatar_Lite_Background;
@sapUiAvatarHoverBorderColor: @sapAvatar_Hover_BorderColor;

@sapUiButtonBackground: @sapButton_Background;
@sapUiButtonBorderColor: @sapButton_BorderColor;
@sapUiButtonBorderWidth: @sapButton_BorderWidth;
@sapUiButtonBorderCornerRadius: @sapButton_BorderCornerRadius;
@sapUiButtonTextColor: @sapButton_TextColor;
@sapUiButtonFontFamily: @sapButton_FontFamily;
@sapUiButtonHoverBackground: @sapButton_Hover_Background;
@sapUiButtonHoverBorderColor: @sapButton_Hover_BorderColor;
@sapUiButtonHoverTextColor: @sapButton_Hover_TextColor;
@sapUiButtonIconColor: @sapButton_IconColor;
@sapUiButtonActiveBackground: @sapButton_Active_Background;
@sapUiButtonActiveBorderColor: @sapButton_Active_BorderColor;
@sapUiButtonActiveTextColor: @sapButton_Active_TextColor;
@sapUiButtonEmphasizedBackground: @sapButton_Emphasized_Background;
@sapUiButtonEmphasizedBorderColor: @sapButton_Emphasized_BorderColor;
@sapUiButtonEmphasizedBorderWidth: @sapButton_Emphasized_BorderWidth;
@sapUiButtonEmphasizedTextColor: @sapButton_Emphasized_TextColor;
@sapUiButtonEmphasizedFontFamily: @sapButton_Emphasized_FontFamily;
@sapUiButtonEmphasizedHoverBackground: @sapButton_Emphasized_Hover_Background;
@sapUiButtonEmphasizedHoverBorderColor: @sapButton_Emphasized_Hover_BorderColor;
@sapUiButtonEmphasizedHoverTextColor: @sapButton_Emphasized_Hover_TextColor;
@sapUiButtonEmphasizedActiveBackground: @sapButton_Emphasized_Active_Background;
@sapUiButtonEmphasizedActiveBorderColor: @sapButton_Emphasized_Active_BorderColor;
@sapUiButtonEmphasizedActiveTextColor: @sapButton_Emphasized_Active_TextColor;
@sapUiButtonEmphasizedTextShadow: @sapButton_Emphasized_TextShadow;
@sapUiButtonEmphasizedFontWeight: @sapButton_Emphasized_FontWeight;
@sapUiButtonRejectBackground: @sapButton_Reject_Background;
@sapUiButtonRejectBorderColor: @sapButton_Reject_BorderColor;
@sapUiButtonRejectTextColor: @sapButton_Reject_TextColor;
@sapUiButtonRejectHoverBackground: @sapButton_Reject_Hover_Background;
@sapUiButtonRejectHoverBorderColor: @sapButton_Reject_Hover_BorderColor;
@sapUiButtonRejectHoverTextColor: @sapButton_Reject_Hover_TextColor;
@sapUiButtonRejectActiveBackground: @sapButton_Reject_Active_Background;
@sapUiButtonRejectActiveBorderColor: @sapButton_Reject_Active_BorderColor;
@sapUiButtonRejectActiveTextColor: @sapButton_Reject_Active_TextColor;
@sapUiButtonRejectSelectedBackground: @sapButton_Reject_Selected_Background;
@sapUiButtonRejectSelectedBorderColor: @sapButton_Reject_Selected_BorderColor;
@sapUiButtonRejectSelectedTextColor: @sapButton_Reject_Selected_TextColor;
@sapUiButtonRejectSelectedHoverBackground: @sapButton_Reject_Selected_Hover_Background;
@sapUiButtonRejectSelectedHoverBorderColor: @sapButton_Reject_Selected_Hover_BorderColor;
@sapUiButtonAcceptBackground: @sapButton_Accept_Background;
@sapUiButtonAcceptBorderColor: @sapButton_Accept_BorderColor;
@sapUiButtonAcceptTextColor: @sapButton_Accept_TextColor;
@sapUiButtonAcceptHoverBackground: @sapButton_Accept_Hover_Background;
@sapUiButtonAcceptHoverBorderColor: @sapButton_Accept_Hover_BorderColor;
@sapUiButtonAcceptHoverTextColor: @sapButton_Accept_Hover_TextColor;
@sapUiButtonAcceptActiveBackground: @sapButton_Accept_Active_Background;
@sapUiButtonAcceptActiveBorderColor: @sapButton_Accept_Active_BorderColor;
@sapUiButtonAcceptActiveTextColor: @sapButton_Accept_Active_TextColor;
@sapUiButtonAcceptSelectedBackground: @sapButton_Accept_Selected_Background;
@sapUiButtonAcceptSelectedBorderColor: @sapButton_Accept_Selected_BorderColor;
@sapUiButtonAcceptSelectedTextColor: @sapButton_Accept_Selected_TextColor;
@sapUiButtonAcceptSelectedHoverBackground: @sapButton_Accept_Selected_Hover_Background;
@sapUiButtonAcceptSelectedHoverBorderColor: @sapButton_Accept_Selected_Hover_BorderColor;
@sapUiButtonLiteBackground: @sapButton_Lite_Background;
@sapUiButtonLiteBorderColor: @sapButton_Lite_BorderColor;
@sapUiButtonLiteTextColor: @sapButton_Lite_TextColor;
@sapUiButtonLiteHoverBackground: @sapButton_Lite_Hover_Background;
@sapUiButtonLiteHoverBorderColor: @sapButton_Lite_Hover_BorderColor;
@sapUiButtonLiteHoverTextColor: @sapButton_Lite_Hover_TextColor;
@sapUiButtonLiteActiveBackground: @sapButton_Lite_Active_Background;
@sapUiButtonLiteActiveBorderColor: @sapButton_Lite_Active_BorderColor;
@sapUiButtonSelectedBackground: @sapButton_Selected_Background;
@sapUiButtonSelectedBorderColor: @sapButton_Selected_BorderColor;
@sapUiButtonSelectedTextColor: @sapButton_Selected_TextColor;
@sapUiButtonSelectedHoverBackground: @sapButton_Selected_Hover_Background;
@sapUiButtonSelectedHoverBorderColor: @sapButton_Selected_Hover_BorderColor;
@sapUiButtonAttentionBackground: @sapButton_Attention_Background;
@sapUiButtonAttentionBorderColor: @sapButton_Attention_BorderColor;
@sapUiButtonAttentionTextColor: @sapButton_Attention_TextColor;
@sapUiButtonAttentionHoverBackground: @sapButton_Attention_Hover_Background;
@sapUiButtonAttentionHoverBorderColor: @sapButton_Attention_Hover_BorderColor;
@sapUiButtonAttentionHoverTextColor: @sapButton_Attention_Hover_TextColor;
@sapUiButtonAttentionActiveBackground: @sapButton_Attention_Active_Background;
@sapUiButtonAttentionActiveBorderColor: @sapButton_Attention_Active_BorderColor;
@sapUiButtonAttentionActiveTextColor: @sapButton_Attention_Active_TextColor;
@sapUiButtonAttentionSelectedBackground: @sapButton_Attention_Selected_Background;
@sapUiButtonAttentionSelectedBorderColor: @sapButton_Attention_Selected_BorderColor;
@sapUiButtonAttentionSelectedTextColor: @sapButton_Attention_Selected_TextColor;
@sapUiButtonAttentionSelectedHoverBackground: @sapButton_Attention_Selected_Hover_Background;
@sapUiButtonAttentionSelectedHoverBorderColor: @sapButton_Attention_Selected_Hover_BorderColor;
@sapUiButtonNegativeBackground: @sapButton_Negative_Background;
@sapUiButtonNegativeBorderColor: @sapButton_Negative_BorderColor;
@sapUiButtonNegativeTextColor: @sapButton_Negative_TextColor;
@sapUiButtonNegativeHoverBackground: @sapButton_Negative_Hover_Background;
@sapUiButtonNegativeHoverBorderColor: @sapButton_Negative_Hover_BorderColor;
@sapUiButtonNegativeHoverTextColor: @sapButton_Negative_Hover_TextColor;
@sapUiButtonNegativeActiveBackground: @sapButton_Negative_Active_Background;
@sapUiButtonNegativeActiveBorderColor: @sapButton_Negative_Active_BorderColor;
@sapUiButtonNegativeActiveTextColor: @sapButton_Negative_Active_TextColor;
@sapUiButtonCriticalBackground: @sapButton_Critical_Background;
@sapUiButtonCriticalBorderColor: @sapButton_Critical_BorderColor;
@sapUiButtonCriticalTextColor: @sapButton_Critical_TextColor;
@sapUiButtonCriticalHoverBackground: @sapButton_Critical_Hover_Background;
@sapUiButtonCriticalHoverBorderColor: @sapButton_Critical_Hover_BorderColor;
@sapUiButtonCriticalHoverTextColor: @sapButton_Critical_Hover_TextColor;
@sapUiButtonCriticalActiveBackground: @sapButton_Critical_Active_Background;
@sapUiButtonCriticalActiveBorderColor: @sapButton_Critical_Active_BorderColor;
@sapUiButtonCriticalActiveTextColor: @sapButton_Critical_Active_TextColor;
@sapUiButtonSuccessBackground: @sapButton_Success_Background;
@sapUiButtonSuccessBorderColor: @sapButton_Success_BorderColor;
@sapUiButtonSuccessTextColor: @sapButton_Success_TextColor;
@sapUiButtonSuccessHoverBackground: @sapButton_Success_Hover_Background;
@sapUiButtonSuccessHoverBorderColor: @sapButton_Success_Hover_BorderColor;
@sapUiButtonSuccessHoverTextColor: @sapButton_Success_Hover_TextColor;
@sapUiButtonSuccessActiveBackground: @sapButton_Success_Active_Background;
@sapUiButtonSuccessActiveBorderColor: @sapButton_Success_Active_BorderColor;
@sapUiButtonSuccessActiveTextColor: @sapButton_Success_Active_TextColor;
@sapUiButtonInformationBackground: @sapButton_Information_Background;
@sapUiButtonInformationBorderColor: @sapButton_Information_BorderColor;
@sapUiButtonInformationTextColor: @sapButton_Information_TextColor;
@sapUiButtonInformationHoverBackground: @sapButton_Information_Hover_Background;
@sapUiButtonInformationHoverBorderColor: @sapButton_Information_Hover_BorderColor;
@sapUiButtonInformationHoverTextColor: @sapButton_Information_Hover_TextColor;
@sapUiButtonInformationActiveBackground: @sapButton_Information_Active_Background;
@sapUiButtonInformationActiveBorderColor: @sapButton_Information_Active_BorderColor;
@sapUiButtonInformationActiveTextColor: @sapButton_Information_Active_TextColor;
@sapUiButtonNeutralBackground: @sapButton_Neutral_Background;
@sapUiButtonNeutralBorderColor: @sapButton_Neutral_BorderColor;
@sapUiButtonNeutralTextColor: @sapButton_Neutral_TextColor;
@sapUiButtonNeutralHoverBackground: @sapButton_Neutral_Hover_Background;
@sapUiButtonNeutralHoverBorderColor: @sapButton_Neutral_Hover_BorderColor;
@sapUiButtonNeutralHoverTextColor: @sapButton_Neutral_Hover_TextColor;
@sapUiButtonNeutralActiveBackground: @sapButton_Neutral_Active_Background;
@sapUiButtonNeutralActiveBorderColor: @sapButton_Neutral_Active_BorderColor;
@sapUiButtonNeutralActiveTextColor: @sapButton_Neutral_Active_TextColor;
@sapUiButtonTrackBackground: @sapButton_Track_Background;
@sapUiButtonTrackBorderColor: @sapButton_Track_BorderColor;
@sapUiButtonTrackTextColor: @sapButton_Track_TextColor;
@sapUiButtonTrackHoverBackground: @sapButton_Track_Hover_Background;
@sapUiButtonTrackHoverBorderColor: @sapButton_Track_Hover_BorderColor;
@sapUiButtonTrackSelectedBackground: @sapButton_Track_Selected_Background;
@sapUiButtonTrackSelectedBorderColor: @sapButton_Track_Selected_BorderColor;
@sapUiButtonTrackSelectedTextColor: @sapButton_Track_Selected_TextColor;
@sapUiButtonTrackSelectedHoverBackground: @sapButton_Track_Selected_Hover_Background;
@sapUiButtonTrackSelectedHoverBorderColor: @sapButton_Track_Selected_Hover_BorderColor;
@sapUiButtonHandleBackground: @sapButton_Handle_Background;
@sapUiButtonHandleBorderColor: @sapButton_Handle_BorderColor;
@sapUiButtonHandleTextColor: @sapButton_Handle_TextColor;
@sapUiButtonHandleHoverBackground: @sapButton_Handle_Hover_Background;
@sapUiButtonHandleHoverBorderColor: @sapButton_Handle_Hover_BorderColor;
@sapUiButtonHandleSelectedBackground: @sapButton_Handle_Selected_Background;
@sapUiButtonHandleSelectedBorderColor: @sapButton_Handle_Selected_BorderColor;
@sapUiButtonHandleSelectedTextColor: @sapButton_Handle_Selected_TextColor;
@sapUiButtonHandleSelectedHoverBackground: @sapButton_Handle_Selected_Hover_Background;
@sapUiButtonHandleSelectedHoverBorderColor: @sapButton_Handle_Selected_Hover_BorderColor;
@sapUiButtonTrackNegativeBackground: @sapButton_Track_Negative_Background;
@sapUiButtonTrackNegativeBorderColor: @sapButton_Track_Negative_BorderColor;
@sapUiButtonTrackNegativeTextColor: @sapButton_Track_Negative_TextColor;
@sapUiButtonTrackNegativeHoverBackground: @sapButton_Track_Negative_Hover_Background;
@sapUiButtonTrackNegativeHoverBorderColor: @sapButton_Track_Negative_Hover_BorderColor;
@sapUiButtonHandleNegativeBackground: @sapButton_Handle_Negative_Background;
@sapUiButtonHandleNegativeBorderColor: @sapButton_Handle_Negative_BorderColor;
@sapUiButtonHandleNegativeTextColor: @sapButton_Handle_Negative_TextColor;
@sapUiButtonHandleNegativeHoverBackground: @sapButton_Handle_Negative_Hover_Background;
@sapUiButtonHandleNegativeHoverBorderColor: @sapButton_Handle_Negative_Hover_BorderColor;
@sapUiButtonTrackPositiveBackground: @sapButton_Track_Positive_Background;
@sapUiButtonTrackPositiveBorderColor: @sapButton_Track_Positive_BorderColor;
@sapUiButtonTrackPositiveTextColor: @sapButton_Track_Positive_TextColor;
@sapUiButtonTrackPositiveHoverBackground: @sapButton_Track_Positive_Hover_Background;
@sapUiButtonTrackPositiveHoverBorderColor: @sapButton_Track_Positive_Hover_BorderColor;
@sapUiButtonHandlePositiveBackground: @sapButton_Handle_Positive_Background;
@sapUiButtonHandlePositiveBorderColor: @sapButton_Handle_Positive_BorderColor;
@sapUiButtonHandlePositiveTextColor: @sapButton_Handle_Positive_TextColor;
@sapUiButtonHandlePositiveHoverBackground: @sapButton_Handle_Positive_Hover_Background;
@sapUiButtonHandlePositiveHoverBorderColor: @sapButton_Handle_Positive_Hover_BorderColor;
@sapUiButtonTokenBackground: @sapButton_TokenBackground;
@sapUiButtonTokenBorderColor: @sapButton_TokenBorderColor;
@sapUiButtonTokenBorderCornerRadius: @sapButton_TokenBorderCornerRadius;
@sapUiButtonSelectedTokenBorderWidth: @sapButton_Selected_TokenBorderWidth;
@sapUiButtonReadOnlyTokenBackground: @sapButton_ReadOnly_TokenBackground;
@sapUiButtonSegmentBorderCornerRadius: @sapButton_Segment_BorderCornerRadius;

@sapUiFieldBackground: @sapField_Background;
@sapUiFieldBackgroundStyle: @sapField_BackgroundStyle;
@sapUiFieldTextColor: @sapField_TextColor;
@sapUiFieldPlaceholderTextColor: @sapField_PlaceholderTextColor;
@sapUiFieldBorderColor: @sapField_BorderColor;
@sapUiFieldHelpBackground: @sapField_HelpBackground;
@sapUiFieldBorderWidth: @sapField_BorderWidth;
@sapUiFieldBorderStyle: @sapField_BorderStyle;
@sapUiFieldBorderCornerRadius: @sapField_BorderCornerRadius;
@sapUiFieldShadow: @sapField_Shadow;
@sapUiFieldHoverBackground: @sapField_Hover_Background;
@sapUiFieldHoverBackgroundStyle: @sapField_Hover_BackgroundStyle;
@sapUiFieldHoverBorderColor: @sapField_Hover_BorderColor;
@sapUiFieldHoverHelpBackground: @sapField_Hover_HelpBackground;
@sapUiFieldHoverShadow: @sapField_Hover_Shadow;
@sapUiFieldHoverInvalidShadow: @sapField_Hover_InvalidShadow;
@sapUiFieldHoverWarningShadow: @sapField_Hover_WarningShadow;
@sapUiFieldHoverSuccessShadow: @sapField_Hover_SuccessShadow;
@sapUiFieldHoverInformationShadow: @sapField_Hover_InformationShadow;
@sapUiFieldActiveBorderColor: @sapField_Active_BorderColor;
@sapUiFieldFocusBackground: @sapField_Focus_Background;
@sapUiFieldFocusBorderColor: @sapField_Focus_BorderColor;
@sapUiFieldFocusHelpBackground: @sapField_Focus_HelpBackground;
@sapUiFieldReadOnlyBackground: @sapField_ReadOnly_Background;
@sapUiFieldReadOnlyBackgroundStyle: @sapField_ReadOnly_BackgroundStyle;
@sapUiFieldReadOnlyBorderColor: @sapField_ReadOnly_BorderColor;
@sapUiFieldReadOnlyBorderStyle: @sapField_ReadOnly_BorderStyle;
@sapUiFieldReadOnlyHelpBackground: @sapField_ReadOnly_HelpBackground;
@sapUiFieldRequiredColor: @sapField_RequiredColor;
@sapUiFieldInvalidColor: @sapField_InvalidColor;
@sapUiFieldInvalidBackground: @sapField_InvalidBackground;
@sapUiFieldInvalidBackgroundStyle: @sapField_InvalidBackgroundStyle;
@sapUiFieldInvalidBorderWidth: @sapField_InvalidBorderWidth;
@sapUiFieldInvalidBorderStyle: @sapField_InvalidBorderStyle;
@sapUiFieldInvalidShadow: @sapField_InvalidShadow;
@sapUiFieldWarningColor: @sapField_WarningColor;
@sapUiFieldWarningBackground: @sapField_WarningBackground;
@sapUiFieldWarningBackgroundStyle: @sapField_WarningBackgroundStyle;
@sapUiFieldWarningBorderWidth: @sapField_WarningBorderWidth;
@sapUiFieldWarningBorderStyle: @sapField_WarningBorderStyle;
@sapUiFieldWarningShadow: @sapField_WarningShadow;
@sapUiFieldSuccessColor: @sapField_SuccessColor;
@sapUiFieldSuccessBackground: @sapField_SuccessBackground;
@sapUiFieldSuccessBackgroundStyle: @sapField_SuccessBackgroundStyle;
@sapUiFieldSuccessBorderWidth: @sapField_SuccessBorderWidth;
@sapUiFieldSuccessBorderStyle: @sapField_SuccessBorderStyle;
@sapUiFieldSuccessShadow: @sapField_SuccessShadow;
@sapUiFieldInformationColor: @sapField_InformationColor;
@sapUiFieldInformationBackground: @sapField_InformationBackground;
@sapUiFieldInformationBackgroundStyle: @sapField_InformationBackgroundStyle;
@sapUiFieldInformationBorderWidth: @sapField_InformationBorderWidth;
@sapUiFieldInformationBorderStyle: @sapField_InformationBorderStyle;
@sapUiFieldInformationShadow: @sapField_InformationShadow;
@sapUiFieldSelectorHoverBackground: @sapField_Selector_Hover_Background;
@sapUiFieldSelectorHoverInvalidBackground: @sapField_Selector_Hover_InvalidBackground;
@sapUiFieldSelectorHoverWarningBackground: @sapField_Selector_Hover_WarningBackground;
@sapUiFieldSelectorHoverSuccessBackground: @sapField_Selector_Hover_SuccessBackground;
@sapUiFieldSelectorHoverInformationBackground: @sapField_Selector_Hover_InformationBackground;
@sapUiFieldPickerBorderColor: @sapField_Picker_BorderColor;
@sapUiFieldPickerBorderWidth: @sapField_Picker_BorderWidth;
@sapUiFieldSelectorBorderStyle: @sapField_Selector_BorderStyle;
@sapUiFieldSelectorReadOnlyBorderStyle: @sapField_Selector_ReadOnly_BorderStyle;
@sapUiFieldSelectorInvalidBorderStyle: @sapField_Selector_InvalidBorderStyle;
@sapUiFieldSelectorWarningBorderStyle: @sapField_Selector_WarningBorderStyle;
@sapUiFieldSelectorSuccessBorderStyle: @sapField_Selector_SuccessBorderStyle;
@sapUiFieldSelectorInformationBorderStyle: @sapField_Selector_InformationBorderStyle;

@sapUiGroupTitleBorderWidth: @sapGroup_TitleBorderWidth;
@sapUiGroupTitleBackground: @sapGroup_TitleBackground;
@sapUiGroupTitleBorderColor: @sapGroup_TitleBorderColor;
@sapUiGroupTitleTextColor: @sapGroup_TitleTextColor;
@sapUiGroupTitleFontSize: @sapGroup_Title_FontSize;
@sapUiGroupContentBackground: @sapGroup_ContentBackground;
@sapUiGroupContentBorderColor: @sapGroup_ContentBorderColor;
@sapUiGroupBorderWidth: @sapGroup_BorderWidth;
@sapUiGroupBorderCornerRadius: @sapGroup_BorderCornerRadius;
@sapUiGroupFooterBackground: @sapGroup_FooterBackground;

@sapUiToolbarBackground: @sapToolbar_Background;
@sapUiToolbarSeparatorColor: @sapToolbar_SeparatorColor;

@sapUiListHeaderBackground: @sapList_HeaderBackground;
@sapUiListHeaderBorderColor: @sapList_HeaderBorderColor;
@sapUiListHeaderTextColor: @sapList_HeaderTextColor;
@sapUiListBorderColor: @sapList_BorderColor;
@sapUiListBorderWidth: @sapList_BorderWidth;
@sapUiListTextColor: @sapList_TextColor;
@sapUiListActiveTextColor: @sapList_Active_TextColor;
@sapUiListActiveBackground: @sapList_Active_Background;
@sapUiListSelectionBackgroundColor: @sapList_SelectionBackgroundColor;
@sapUiListSelectionBorderColor: @sapList_SelectionBorderColor;
@sapUiListHoverSelectionBackground: @sapList_Hover_SelectionBackground;
@sapUiListBackground: @sapList_Background;
@sapUiListHoverBackground: @sapList_Hover_Background;
@sapUiListAlternatingBackground: @sapList_AlternatingBackground;
@sapUiListGroupHeaderBackground: @sapList_GroupHeaderBackground;
@sapUiListGroupHeaderBorderColor: @sapList_GroupHeaderBorderColor;
@sapUiListGroupHeaderTextColor: @sapList_GroupHeaderTextColor;
@sapUiListTableGroupHeaderBackground: @sapList_TableGroupHeaderBackground;
@sapUiListTableGroupHeaderBorderColor: @sapList_TableGroupHeaderBorderColor;
@sapUiListTableGroupHeaderTextColor: @sapList_TableGroupHeaderTextColor;
@sapUiListFooterBackground: @sapList_FooterBackground;
@sapUiListFooterTextColor: @sapList_FooterTextColor;
@sapUiListTableFooterBorder: @sapList_TableFooterBorder;
@sapUiListTableFixedBorderColor: @sapList_TableFixedBorderColor;
@sapUiListTableFixedColumnBorderWidth: @sapList_TableFixedColumnBorderWidth;
@sapUiListTableFixedRowBorderWidth: @sapList_TableFixedRowBorderWidth;

@sapUiMessageBorderWidth: @sapMessage_BorderWidth;
@sapUiMessageErrorBorderColor: @sapMessage_ErrorBorderColor;
@sapUiMessageWarningBorderColor: @sapMessage_WarningBorderColor;
@sapUiMessageSuccessBorderColor: @sapMessage_SuccessBorderColor;
@sapUiMessageInformationBorderColor: @sapMessage_InformationBorderColor;
@sapUiMessageButtonHoverBackground: @sapMessage_Button_Hover_Background;

@sapUiPopoverBorderCornerRadius: @sapPopover_BorderCornerRadius;

@sapUiProgressBackground: @sapProgress_Background;
@sapUiProgressBorderColor: @sapProgress_BorderColor;
@sapUiProgressTextColor: @sapProgress_TextColor;
@sapUiProgressFontSize: @sapProgress_FontSize;
@sapUiProgressNegativeBackground: @sapProgress_NegativeBackground;
@sapUiProgressNegativeBorderColor: @sapProgress_NegativeBorderColor;
@sapUiProgressNegativeTextColor: @sapProgress_NegativeTextColor;
@sapUiProgressCriticalBackground: @sapProgress_CriticalBackground;
@sapUiProgressCriticalBorderColor: @sapProgress_CriticalBorderColor;
@sapUiProgressCriticalTextColor: @sapProgress_CriticalTextColor;
@sapUiProgressPositiveBackground: @sapProgress_PositiveBackground;
@sapUiProgressPositiveBorderColor: @sapProgress_PositiveBorderColor;
@sapUiProgressPositiveTextColor: @sapProgress_PositiveTextColor;
@sapUiProgressInformationBackground: @sapProgress_InformationBackground;
@sapUiProgressInformationBorderColor: @sapProgress_InformationBorderColor;
@sapUiProgressInformationTextColor: @sapProgress_InformationTextColor;
@sapUiProgressValueBackground: @sapProgress_Value_Background;
@sapUiProgressValueBorderColor: @sapProgress_Value_BorderColor;
@sapUiProgressValueTextColor: @sapProgress_Value_TextColor;
@sapUiProgressValueNegativeBackground: @sapProgress_Value_NegativeBackground;
@sapUiProgressValueNegativeBorderColor: @sapProgress_Value_NegativeBorderColor;
@sapUiProgressValueNegativeTextColor: @sapProgress_Value_NegativeTextColor;
@sapUiProgressValueCriticalBackground: @sapProgress_Value_CriticalBackground;
@sapUiProgressValueCriticalBorderColor: @sapProgress_Value_CriticalBorderColor;
@sapUiProgressValueCriticalTextColor: @sapProgress_Value_CriticalTextColor;
@sapUiProgressValuePositiveBackground: @sapProgress_Value_PositiveBackground;
@sapUiProgressValuePositiveBorderColor: @sapProgress_Value_PositiveBorderColor;
@sapUiProgressValuePositiveTextColor: @sapProgress_Value_PositiveTextColor;
@sapUiProgressValueInformationBackground: @sapProgress_Value_InformationBackground;
@sapUiProgressValueInformationBorderColor: @sapProgress_Value_InformationBorderColor;
@sapUiProgressValueInformationTextColor: @sapProgress_Value_InformationTextColor;

@sapUiScrollBarFaceColor: @sapScrollBar_FaceColor;
@sapUiScrollBarTrackColor: @sapScrollBar_TrackColor;
@sapUiScrollBarBorderColor: @sapScrollBar_BorderColor;
@sapUiScrollBarSymbolColor: @sapScrollBar_SymbolColor;
@sapUiScrollBarDimension: @sapScrollBar_Dimension;
@sapUiScrollBarHoverFaceColor: @sapScrollBar_Hover_FaceColor;

@sapUiSliderBackground: @sapSlider_Background;
@sapUiSliderBorderColor: @sapSlider_BorderColor;
@sapUiSliderSelectedBackground: @sapSlider_Selected_Background;
@sapUiSliderSelectedBorderColor: @sapSlider_Selected_BorderColor;
@sapUiSliderSelectedDimension: @sapSlider_Selected_Dimension;
@sapUiSliderHandleBackground: @sapSlider_HandleBackground;
@sapUiSliderHandleBorderColor: @sapSlider_HandleBorderColor;
@sapUiSliderRangeHandleBackground: @sapSlider_RangeHandleBackground;
@sapUiSliderHoverHandleBackground: @sapSlider_Hover_HandleBackground;
@sapUiSliderHoverHandleBorderColor: @sapSlider_Hover_HandleBorderColor;
@sapUiSliderHoverRangeHandleBackground: @sapSlider_Hover_RangeHandleBackground;
@sapUiSliderActiveHandleBackground: @sapSlider_Active_HandleBackground;
@sapUiSliderActiveHandleBorderColor: @sapSlider_Active_HandleBorderColor;
@sapUiSliderActiveRangeHandleBackground: @sapSlider_Active_RangeHandleBackground;

@sapUiPageHeaderBackground: @sapPageHeader_Background;
@sapUiPageHeaderBorderColor: @sapPageHeader_BorderColor;
@sapUiPageHeaderTextColor: @sapPageHeader_TextColor;

@sapUiPageFooterBackground: @sapPageFooter_Background;
@sapUiPageFooterBorderColor: @sapPageFooter_BorderColor;
@sapUiPageFooterTextColor: @sapPageFooter_TextColor;

@sapUiInfobarBackground: @sapInfobar_Background;
@sapUiInfobarHoverBackground: @sapInfobar_Hover_Background;
@sapUiInfobarActiveBackground: @sapInfobar_Active_Background;
@sapUiInfobarNonInteractiveBackground: @sapInfobar_NonInteractive_Background;
@sapUiInfobarTextColor: @sapInfobar_TextColor;

@sapUiObjectHeaderBackground: @sapObjectHeader_Background;
@sapUiObjectHeaderHoverBackground: @sapObjectHeader_Hover_Background;
@sapUiObjectHeaderBorderColor: @sapObjectHeader_BorderColor;
@sapUiObjectHeaderTitleTextColor: @sapObjectHeader_Title_TextColor;
@sapUiObjectHeaderTitleFontSize: @sapObjectHeader_Title_FontSize;
@sapUiObjectHeaderTitleSnappedFontSize: @sapObjectHeader_Title_SnappedFontSize;
@sapUiObjectHeaderTitleFontFamily: @sapObjectHeader_Title_FontFamily;
@sapUiObjectHeaderSubtitleTextColor: @sapObjectHeader_Subtitle_TextColor;

@sapUiBlockLayerBackground: @sapBlockLayer_Background;
@sapUiBlockLayerOpacity: @sapBlockLayer_Opacity;

@sapUiTabTextColor: @sapTab_TextColor;
@sapUiTabForegroundColor: @sapTab_ForegroundColor;
@sapUiTabIconColor: @sapTab_IconColor;
@sapUiTabBackground: @sapTab_Background;
@sapUiTabSelectedTextColor: @sapTab_Selected_TextColor;
@sapUiTabSelectedIconColor: @sapTab_Selected_IconColor;
@sapUiTabSelectedBackground: @sapTab_Selected_Background;
@sapUiTabSelectedIndicatorDimension: @sapTab_Selected_Indicator_Dimension;
@sapUiTabPositiveTextColor: @sapTab_Positive_TextColor;
@sapUiTabPositiveForegroundColor: @sapTab_Positive_ForegroundColor;
@sapUiTabPositiveIconColor: @sapTab_Positive_IconColor;
@sapUiTabPositiveSelectedTextColor: @sapTab_Positive_Selected_TextColor;
@sapUiTabPositiveSelectedIconColor: @sapTab_Positive_Selected_IconColor;
@sapUiTabPositiveSelectedBackground: @sapTab_Positive_Selected_Background;
@sapUiTabNegativeTextColor: @sapTab_Negative_TextColor;
@sapUiTabNegativeForegroundColor: @sapTab_Negative_ForegroundColor;
@sapUiTabNegativeIconColor: @sapTab_Negative_IconColor;
@sapUiTabNegativeSelectedTextColor: @sapTab_Negative_Selected_TextColor;
@sapUiTabNegativeSelectedIconColor: @sapTab_Negative_Selected_IconColor;
@sapUiTabNegativeSelectedBackground: @sapTab_Negative_Selected_Background;
@sapUiTabCriticalTextColor: @sapTab_Critical_TextColor;
@sapUiTabCriticalForegroundColor: @sapTab_Critical_ForegroundColor;
@sapUiTabCriticalIconColor: @sapTab_Critical_IconColor;
@sapUiTabCriticalSelectedTextColor: @sapTab_Critical_Selected_TextColor;
@sapUiTabCriticalSelectedIconColor: @sapTab_Critical_Selected_IconColor;
@sapUiTabCriticalSelectedBackground: @sapTab_Critical_Selected_Background;
@sapUiTabNeutralTextColor: @sapTab_Neutral_TextColor;
@sapUiTabNeutralForegroundColor: @sapTab_Neutral_ForegroundColor;
@sapUiTabNeutralIconColor: @sapTab_Neutral_IconColor;
@sapUiTabNeutralSelectedTextColor: @sapTab_Neutral_Selected_TextColor;
@sapUiTabNeutralSelectedIconColor: @sapTab_Neutral_Selected_IconColor;
@sapUiTabNeutralSelectedBackground: @sapTab_Neutral_Selected_Background;

@sapUiTileBackground: @sapTile_Background;
@sapUiTileHoverBackground: @sapTile_Hover_Background;
@sapUiTileActiveBackground: @sapTile_Active_Background;
@sapUiTileBorderColor: @sapTile_BorderColor;
@sapUiTileBorderCornerRadius: @sapTile_BorderCornerRadius;
@sapUiTileTitleTextColor: @sapTile_TitleTextColor;
@sapUiTileTextColor: @sapTile_TextColor;
@sapUiTileIconColor: @sapTile_IconColor;
@sapUiTileSeparatorColor: @sapTile_SeparatorColor;
@sapUiTileInteractiveBorderColor: @sapTile_Interactive_BorderColor;
@sapUiTileOverlayBackground: @sapTile_OverlayBackground;
@sapUiTileOverlayForegroundColor: @sapTile_OverlayForegroundColor;
@sapUiTileHoverContentBackground: @sapTile_Hover_ContentBackground;
@sapUiTileActiveContentBackground: @sapTile_Active_ContentBackground;

// RatingIndicator
@sapUiRIIconPaddingDisplayOnly: 0.125rem;
@sapUiRIIconSizeDisplayOnly: 1rem;


// =====================================
// Accent Colors
// =====================================

@sapUiAccent1: @sapAccentColor1;
@sapUiAccent2: @sapAccentColor2;
@sapUiAccent3: @sapAccentColor3;
@sapUiAccent4: @sapAccentColor4;
@sapUiAccent5: @sapAccentColor5;
@sapUiAccent6: @sapAccentColor6;
@sapUiAccent7: @sapAccentColor7;
@sapUiAccent8: @sapAccentColor8;
@sapUiAccent9: @sapAccentColor9;
@sapUiAccent10: @sapAccentColor10;

@sapUiAccentBackgroundColor1: @sapAccentBackgroundColor1;
@sapUiAccentBackgroundColor2: @sapAccentBackgroundColor2;
@sapUiAccentBackgroundColor3: @sapAccentBackgroundColor3;
@sapUiAccentBackgroundColor4: @sapAccentBackgroundColor4;
@sapUiAccentBackgroundColor5: @sapAccentBackgroundColor5;
@sapUiAccentBackgroundColor6: @sapAccentBackgroundColor6;
@sapUiAccentBackgroundColor7: @sapAccentBackgroundColor7;
@sapUiAccentBackgroundColor8: @sapAccentBackgroundColor8;
@sapUiAccentBackgroundColor9: @sapAccentBackgroundColor9;
@sapUiAccentBackgroundColor10: @sapAccentBackgroundColor10;


// =====================================
// Indication Colors
// =====================================

@sapUiIndication1: @sapIndicationColor_1;
@sapUiIndication1Background: @sapIndicationColor_1_Background;
@sapUiIndication1BorderColor: @sapIndicationColor_1_BorderColor;
@sapUiIndication1TextColor: @sapIndicationColor_1_TextColor;
@sapUiIndication1HoverBackground: @sapIndicationColor_1_Hover_Background;
@sapUiIndication1ActiveBackground: @sapIndicationColor_1_Active_Background;
@sapUiIndication1ActiveBorderColor: @sapIndicationColor_1_Active_BorderColor;
@sapUiIndication1ActiveTextColor: @sapIndicationColor_1_Active_TextColor;
@sapUiIndication1SelectedBackground: @sapIndicationColor_1_Selected_Background;
@sapUiIndication1SelectedBorderColor: @sapIndicationColor_1_Selected_BorderColor;
@sapUiIndication1SelectedTextColor: @sapIndicationColor_1_Selected_TextColor;
@sapUiIndication1b: @sapIndicationColor_1b;
@sapUiIndication1bTextColor: @sapIndicationColor_1b_TextColor;
@sapUiIndication1bBackground: @sapIndicationColor_1b_Background;
@sapUiIndication1bBorderColor: @sapIndicationColor_1b_BorderColor;
@sapUiIndication1bHoverBackground: @sapIndicationColor_1b_Hover_Background;
@sapUiIndication2: @sapIndicationColor_2;
@sapUiIndication2Background: @sapIndicationColor_2_Background;
@sapUiIndication2BorderColor: @sapIndicationColor_2_BorderColor;
@sapUiIndication2TextColor: @sapIndicationColor_2_TextColor;
@sapUiIndication2HoverBackground: @sapIndicationColor_2_Hover_Background;
@sapUiIndication2ActiveBackground: @sapIndicationColor_2_Active_Background;
@sapUiIndication2ActiveBorderColor: @sapIndicationColor_2_Active_BorderColor;
@sapUiIndication2ActiveTextColor: @sapIndicationColor_2_Active_TextColor;
@sapUiIndication2SelectedBackground: @sapIndicationColor_2_Selected_Background;
@sapUiIndication2SelectedBorderColor: @sapIndicationColor_2_Selected_BorderColor;
@sapUiIndication2SelectedTextColor: @sapIndicationColor_2_Selected_TextColor;
@sapUiIndication2b: @sapIndicationColor_2b;
@sapUiIndication2bTextColor: @sapIndicationColor_2b_TextColor;
@sapUiIndication2bBackground: @sapIndicationColor_2b_Background;
@sapUiIndication2bBorderColor: @sapIndicationColor_2b_BorderColor;
@sapUiIndication2bHoverBackground: @sapIndicationColor_2b_Hover_Background;
@sapUiIndication3: @sapIndicationColor_3;
@sapUiIndication3Background: @sapIndicationColor_3_Background;
@sapUiIndication3BorderColor: @sapIndicationColor_3_BorderColor;
@sapUiIndication3TextColor: @sapIndicationColor_3_TextColor;
@sapUiIndication3HoverBackground: @sapIndicationColor_3_Hover_Background;
@sapUiIndication3ActiveBackground: @sapIndicationColor_3_Active_Background;
@sapUiIndication3ActiveBorderColor: @sapIndicationColor_3_Active_BorderColor;
@sapUiIndication3ActiveTextColor: @sapIndicationColor_3_Active_TextColor;
@sapUiIndication3SelectedBackground: @sapIndicationColor_3_Selected_Background;
@sapUiIndication3SelectedBorderColor: @sapIndicationColor_3_Selected_BorderColor;
@sapUiIndication3SelectedTextColor: @sapIndicationColor_3_Selected_TextColor;
@sapUiIndication3b: @sapIndicationColor_3b;
@sapUiIndication3bTextColor: @sapIndicationColor_3b_TextColor;
@sapUiIndication3bBackground: @sapIndicationColor_3b_Background;
@sapUiIndication3bBorderColor: @sapIndicationColor_3b_BorderColor;
@sapUiIndication3bHoverBackground: @sapIndicationColor_3b_Hover_Background;
@sapUiIndication4: @sapIndicationColor_4;
@sapUiIndication4Background: @sapIndicationColor_4_Background;
@sapUiIndication4BorderColor: @sapIndicationColor_4_BorderColor;
@sapUiIndication4TextColor: @sapIndicationColor_4_TextColor;
@sapUiIndication4HoverBackground: @sapIndicationColor_4_Hover_Background;
@sapUiIndication4ActiveBackground: @sapIndicationColor_4_Active_Background;
@sapUiIndication4ActiveBorderColor: @sapIndicationColor_4_Active_BorderColor;
@sapUiIndication4ActiveTextColor: @sapIndicationColor_4_Active_TextColor;
@sapUiIndication4SelectedBackground: @sapIndicationColor_4_Selected_Background;
@sapUiIndication4SelectedBorderColor: @sapIndicationColor_4_Selected_BorderColor;
@sapUiIndication4SelectedTextColor: @sapIndicationColor_4_Selected_TextColor;
@sapUiIndication4b: @sapIndicationColor_4b;
@sapUiIndication4bTextColor: @sapIndicationColor_4b_TextColor;
@sapUiIndication4bBackground: @sapIndicationColor_4b_Background;
@sapUiIndication4bBorderColor: @sapIndicationColor_4b_BorderColor;
@sapUiIndication4bHoverBackground: @sapIndicationColor_4b_Hover_Background;
@sapUiIndication5: @sapIndicationColor_5;
@sapUiIndication5Background: @sapIndicationColor_5_Background;
@sapUiIndication5BorderColor: @sapIndicationColor_5_BorderColor;
@sapUiIndication5TextColor: @sapIndicationColor_5_TextColor;
@sapUiIndication5HoverBackground: @sapIndicationColor_5_Hover_Background;
@sapUiIndication5ActiveBackground: @sapIndicationColor_5_Active_Background;
@sapUiIndication5ActiveBorderColor: @sapIndicationColor_5_Active_BorderColor;
@sapUiIndication5ActiveTextColor: @sapIndicationColor_5_Active_TextColor;
@sapUiIndication5SelectedBackground: @sapIndicationColor_5_Selected_Background;
@sapUiIndication5SelectedBorderColor: @sapIndicationColor_5_Selected_BorderColor;
@sapUiIndication5SelectedTextColor: @sapIndicationColor_5_Selected_TextColor;
@sapUiIndication5b: @sapIndicationColor_5b;
@sapUiIndication5bTextColor: @sapIndicationColor_5b_TextColor;
@sapUiIndication5bBackground: @sapIndicationColor_5b_Background;
@sapUiIndication5bBorderColor: @sapIndicationColor_5b_BorderColor;
@sapUiIndication5bHoverBackground: @sapIndicationColor_5b_Hover_Background;
@sapUiIndication6: @sapIndicationColor_6;
@sapUiIndication6Background: @sapIndicationColor_6_Background;
@sapUiIndication6BorderColor: @sapIndicationColor_6_BorderColor;
@sapUiIndication6TextColor: @sapIndicationColor_6_TextColor;
@sapUiIndication6HoverBackground: @sapIndicationColor_6_Hover_Background;
@sapUiIndication6ActiveBackground: @sapIndicationColor_6_Active_Background;
@sapUiIndication6ActiveBorderColor: @sapIndicationColor_6_Active_BorderColor;
@sapUiIndication6ActiveTextColor: @sapIndicationColor_6_Active_TextColor;
@sapUiIndication6SelectedBackground: @sapIndicationColor_6_Selected_Background;
@sapUiIndication6SelectedBorderColor: @sapIndicationColor_6_Selected_BorderColor;
@sapUiIndication6SelectedTextColor: @sapIndicationColor_6_Selected_TextColor;
@sapUiIndication6b: @sapIndicationColor_6b;
@sapUiIndication6bTextColor: @sapIndicationColor_6b_TextColor;
@sapUiIndication6bBackground: @sapIndicationColor_6b_Background;
@sapUiIndication6bBorderColor: @sapIndicationColor_6b_BorderColor;
@sapUiIndication6bHoverBackground: @sapIndicationColor_6b_Hover_Background;
@sapUiIndication7: @sapIndicationColor_7;
@sapUiIndication7Background: @sapIndicationColor_7_Background;
@sapUiIndication7BorderColor: @sapIndicationColor_7_BorderColor;
@sapUiIndication7TextColor: @sapIndicationColor_7_TextColor;
@sapUiIndication7HoverBackground: @sapIndicationColor_7_Hover_Background;
@sapUiIndication7ActiveBackground: @sapIndicationColor_7_Active_Background;
@sapUiIndication7ActiveBorderColor: @sapIndicationColor_7_Active_BorderColor;
@sapUiIndication7ActiveTextColor: @sapIndicationColor_7_Active_TextColor;
@sapUiIndication7SelectedBackground: @sapIndicationColor_7_Selected_Background;
@sapUiIndication7SelectedBorderColor: @sapIndicationColor_7_Selected_BorderColor;
@sapUiIndication7SelectedTextColor: @sapIndicationColor_7_Selected_TextColor;
@sapUiIndication7b: @sapIndicationColor_7b;
@sapUiIndication7bTextColor: @sapIndicationColor_7b_TextColor;
@sapUiIndication7bBackground: @sapIndicationColor_7b_Background;
@sapUiIndication7bBorderColor: @sapIndicationColor_7b_BorderColor;
@sapUiIndication7bHoverBackground: @sapIndicationColor_7b_Hover_Background;
@sapUiIndication8: @sapIndicationColor_8;
@sapUiIndication8Background: @sapIndicationColor_8_Background;
@sapUiIndication8BorderColor: @sapIndicationColor_8_BorderColor;
@sapUiIndication8TextColor: @sapIndicationColor_8_TextColor;
@sapUiIndication8HoverBackground: @sapIndicationColor_8_Hover_Background;
@sapUiIndication8ActiveBackground: @sapIndicationColor_8_Active_Background;
@sapUiIndication8ActiveBorderColor: @sapIndicationColor_8_Active_BorderColor;
@sapUiIndication8ActiveTextColor: @sapIndicationColor_8_Active_TextColor;
@sapUiIndication8SelectedBackground: @sapIndicationColor_8_Selected_Background;
@sapUiIndication8SelectedBorderColor: @sapIndicationColor_8_Selected_BorderColor;
@sapUiIndication8SelectedTextColor: @sapIndicationColor_8_Selected_TextColor;
@sapUiIndication8b: @sapIndicationColor_8b;
@sapUiIndication8bTextColor: @sapIndicationColor_8b_TextColor;
@sapUiIndication8bBackground: @sapIndicationColor_8b_Background;
@sapUiIndication8bBorderColor: @sapIndicationColor_8b_BorderColor;
@sapUiIndication8bHoverBackground: @sapIndicationColor_8b_Hover_Background;
@sapUiIndication9: @sapIndicationColor_9;
@sapUiIndication9Background: @sapIndicationColor_9_Background;
@sapUiIndication9BorderColor: @sapIndicationColor_9_BorderColor;
@sapUiIndication9TextColor: @sapIndicationColor_9_TextColor;
@sapUiIndication9HoverBackground: @sapIndicationColor_9_Hover_Background;
@sapUiIndication9ActiveBackground: @sapIndicationColor_9_Active_Background;
@sapUiIndication9ActiveBorderColor: @sapIndicationColor_9_Active_BorderColor;
@sapUiIndication9ActiveTextColor: @sapIndicationColor_9_Active_TextColor;
@sapUiIndication9SelectedBackground: @sapIndicationColor_9_Selected_Background;
@sapUiIndication9SelectedBorderColor: @sapIndicationColor_9_Selected_BorderColor;
@sapUiIndication9SelectedTextColor: @sapIndicationColor_9_Selected_TextColor;
@sapUiIndication9b: @sapIndicationColor_9b;
@sapUiIndication9bTextColor: @sapIndicationColor_9b_TextColor;
@sapUiIndication9bBackground: @sapIndicationColor_9b_Background;
@sapUiIndication9bBorderColor: @sapIndicationColor_9b_BorderColor;
@sapUiIndication9bHoverBackground: @sapIndicationColor_9b_Hover_Background;
@sapUiIndication10: @sapIndicationColor_10;
@sapUiIndication10Background: @sapIndicationColor_10_Background;
@sapUiIndication10BorderColor: @sapIndicationColor_10_BorderColor;
@sapUiIndication10TextColor: @sapIndicationColor_10_TextColor;
@sapUiIndication10HoverBackground: @sapIndicationColor_10_Hover_Background;
@sapUiIndication10ActiveBackground: @sapIndicationColor_10_Active_Background;
@sapUiIndication10ActiveBorderColor: @sapIndicationColor_10_Active_BorderColor;
@sapUiIndication10ActiveTextColor: @sapIndicationColor_10_Active_TextColor;
@sapUiIndication10SelectedBackground: @sapIndicationColor_10_Selected_Background;
@sapUiIndication10SelectedBorderColor: @sapIndicationColor_10_Selected_BorderColor;
@sapUiIndication10SelectedTextColor: @sapIndicationColor_10_Selected_TextColor;
@sapUiIndication10b: @sapIndicationColor_10b;
@sapUiIndication10bTextColor: @sapIndicationColor_10b_TextColor;
@sapUiIndication10bBackground: @sapIndicationColor_10b_Background;
@sapUiIndication10bBorderColor: @sapIndicationColor_10b_BorderColor;
@sapUiIndication10bHoverBackground: @sapIndicationColor_10b_Hover_Background;


// =====================================
// Legend Colors
// =====================================

@sapUiLegendWorkingBackground: @sapLegend_WorkingBackground;
@sapUiLegendNonWorkingBackground: @sapLegend_NonWorkingBackground;
@sapUiLegendCurrentDateTime: @sapLegend_CurrentDateTime;

@sapUiLegend1: @sapLegendColor1;
@sapUiLegend2: @sapLegendColor2;
@sapUiLegend3: @sapLegendColor3;
@sapUiLegend4: @sapLegendColor4;
@sapUiLegend5: @sapLegendColor5;
@sapUiLegend6: @sapLegendColor6;
@sapUiLegend7: @sapLegendColor7;
@sapUiLegend8: @sapLegendColor8;
@sapUiLegend9: @sapLegendColor9;
@sapUiLegend10: @sapLegendColor10;
@sapUiLegend11: @sapLegendColor11;
@sapUiLegend12: @sapLegendColor12;
@sapUiLegend13: @sapLegendColor13;
@sapUiLegend14: @sapLegendColor14;
@sapUiLegend15: @sapLegendColor15;
@sapUiLegend16: @sapLegendColor16;
@sapUiLegend17: @sapLegendColor17;
@sapUiLegend18: @sapLegendColor18;
@sapUiLegend19: @sapLegendColor19;
@sapUiLegend20: @sapLegendColor20;

@sapUiLegendBackgroundColor1: @sapLegendBackgroundColor1;
@sapUiLegendBackgroundColor2: @sapLegendBackgroundColor2;
@sapUiLegendBackgroundColor3: @sapLegendBackgroundColor3;
@sapUiLegendBackgroundColor4: @sapLegendBackgroundColor4;
@sapUiLegendBackgroundColor5: @sapLegendBackgroundColor5;
@sapUiLegendBackgroundColor6: @sapLegendBackgroundColor6;
@sapUiLegendBackgroundColor7: @sapLegendBackgroundColor7;
@sapUiLegendBackgroundColor8: @sapLegendBackgroundColor8;
@sapUiLegendBackgroundColor9: @sapLegendBackgroundColor9;
@sapUiLegendBackgroundColor10: @sapLegendBackgroundColor10;
@sapUiLegendBackgroundColor11: @sapLegendBackgroundColor11;
@sapUiLegendBackgroundColor12: @sapLegendBackgroundColor12;
@sapUiLegendBackgroundColor13: @sapLegendBackgroundColor13;
@sapUiLegendBackgroundColor14: @sapLegendBackgroundColor14;
@sapUiLegendBackgroundColor15: @sapLegendBackgroundColor15;
@sapUiLegendBackgroundColor16: @sapLegendBackgroundColor16;
@sapUiLegendBackgroundColor17: @sapLegendBackgroundColor17;
@sapUiLegendBackgroundColor18: @sapLegendBackgroundColor18;
@sapUiLegendBackgroundColor19: @sapLegendBackgroundColor19;
@sapUiLegendBackgroundColor20: @sapLegendBackgroundColor20;


// =====================================
// Chart Colors
// =====================================

@sapUiChartBackground: @sapChart_Background;
@sapUiChartContrastTextShadow: @sapChart_ContrastTextShadow;
@sapUiChartContrastShadowColor: @sapChart_ContrastShadowColor;
@sapUiChartContrastLineColor: @sapChart_ContrastLineColor;
@sapUiChartLineColor1: @sapChart_LineColor_1;
@sapUiChartLineColor2: @sapChart_LineColor_2;
@sapUiChartLineColor3: @sapChart_LineColor_3;
@sapUiChartChoroplethBackground: @sapChart_Choropleth_Background;
@sapUiChartChoroplethRegionBackground: @sapChart_ChoroplethRegion_Background;
@sapUiChartChoroplethRegionBorderColor: @sapChart_ChoroplethRegion_BorderColor;
@sapUiChartDataTextColor: @sapChart_Data_TextColor;
@sapUiChartDataContrastTextColor: @sapChart_Data_ContrastTextColor;
@sapUiChartDataInteractiveColor: @sapChart_Data_InteractiveColor;
@sapUiChartDataActiveBackground: @sapChart_Data_Active_Background;

@sapUiChart1: @sapChart_OrderedColor_1;
@sapUiChart2: @sapChart_OrderedColor_2;
@sapUiChart3: @sapChart_OrderedColor_3;
@sapUiChart4: @sapChart_OrderedColor_4;
@sapUiChart5: @sapChart_OrderedColor_5;
@sapUiChart6: @sapChart_OrderedColor_6;
@sapUiChart7: @sapChart_OrderedColor_7;
@sapUiChart8: @sapChart_OrderedColor_8;
@sapUiChart9: @sapChart_OrderedColor_9;
@sapUiChart10: @sapChart_OrderedColor_10;
@sapUiChart11: @sapChart_OrderedColor_11;
@sapUiChart12: @sapChart_OrderedColor_12;

@sapUiChartBad: @sapChart_Bad;
@sapUiChartCritical: @sapChart_Critical;
@sapUiChartGood: @sapChart_Good;
@sapUiChartNeutral: @sapChart_Neutral;

@sapUiChartSequence1Plus3: @sapChart_Sequence_1_Plus3;
@sapUiChartSequence1Plus3TextColor: @sapChart_Sequence_1_Plus3_TextColor;
@sapUiChartSequence1Plus3TextShadow: @sapChart_Sequence_1_Plus3_TextShadow;
@sapUiChartSequence1Plus2: @sapChart_Sequence_1_Plus2;
@sapUiChartSequence1Plus2TextColor: @sapChart_Sequence_1_Plus2_TextColor;
@sapUiChartSequence1Plus2TextShadow: @sapChart_Sequence_1_Plus2_TextShadow;
@sapUiChartSequence1Plus1: @sapChart_Sequence_1_Plus1;
@sapUiChartSequence1Plus1TextColor: @sapChart_Sequence_1_Plus1_TextColor;
@sapUiChartSequence1Plus1TextShadow: @sapChart_Sequence_1_Plus1_TextShadow;
@sapUiChartSequence1: @sapChart_Sequence_1;
@sapUiChartSequence1TextColor: @sapChart_Sequence_1_TextColor;
@sapUiChartSequence1TextShadow: @sapChart_Sequence_1_TextShadow;
@sapUiChartSequence1BorderColor: @sapChart_Sequence_1_BorderColor;
@sapUiChartSequence1Minus1: @sapChart_Sequence_1_Minus1;
@sapUiChartSequence1Minus1TextColor: @sapChart_Sequence_1_Minus1_TextColor;
@sapUiChartSequence1Minus1TextShadow: @sapChart_Sequence_1_Minus1_TextShadow;
@sapUiChartSequence1Minus2: @sapChart_Sequence_1_Minus2;
@sapUiChartSequence1Minus2TextColor: @sapChart_Sequence_1_Minus2_TextColor;
@sapUiChartSequence1Minus2TextShadow: @sapChart_Sequence_1_Minus2_TextShadow;
@sapUiChartSequence1Minus3: @sapChart_Sequence_1_Minus3;
@sapUiChartSequence1Minus3TextColor: @sapChart_Sequence_1_Minus3_TextColor;
@sapUiChartSequence1Minus3TextShadow: @sapChart_Sequence_1_Minus3_TextShadow;
@sapUiChartSequence1Minus4: @sapChart_Sequence_1_Minus4;
@sapUiChartSequence1Minus4TextColor: @sapChart_Sequence_1_Minus4_TextColor;
@sapUiChartSequence1Minus4TextShadow: @sapChart_Sequence_1_Minus4_TextShadow;
@sapUiChartSequence1Minus5: @sapChart_Sequence_1_Minus5;
@sapUiChartSequence1Minus5TextColor: @sapChart_Sequence_1_Minus5_TextColor;
@sapUiChartSequence1Minus5TextShadow: @sapChart_Sequence_1_Minus5_TextShadow;
@sapUiChartSequence2Plus3: @sapChart_Sequence_2_Plus3;
@sapUiChartSequence2Plus3TextColor: @sapChart_Sequence_2_Plus3_TextColor;
@sapUiChartSequence2Plus3TextShadow: @sapChart_Sequence_2_Plus3_TextShadow;
@sapUiChartSequence2Plus2: @sapChart_Sequence_2_Plus2;
@sapUiChartSequence2Plus2TextColor: @sapChart_Sequence_2_Plus2_TextColor;
@sapUiChartSequence2Plus2TextShadow: @sapChart_Sequence_2_Plus2_TextShadow;
@sapUiChartSequence2Plus1: @sapChart_Sequence_2_Plus1;
@sapUiChartSequence2Plus1TextColor: @sapChart_Sequence_2_Plus1_TextColor;
@sapUiChartSequence2Plus1TextShadow: @sapChart_Sequence_2_Plus1_TextShadow;
@sapUiChartSequence2: @sapChart_Sequence_2;
@sapUiChartSequence2TextColor: @sapChart_Sequence_2_TextColor;
@sapUiChartSequence2TextShadow: @sapChart_Sequence_2_TextShadow;
@sapUiChartSequence2BorderColor: @sapChart_Sequence_2_BorderColor;
@sapUiChartSequence2Minus1: @sapChart_Sequence_2_Minus1;
@sapUiChartSequence2Minus1TextColor: @sapChart_Sequence_2_Minus1_TextColor;
@sapUiChartSequence2Minus1TextShadow: @sapChart_Sequence_2_Minus1_TextShadow;
@sapUiChartSequence2Minus2: @sapChart_Sequence_2_Minus2;
@sapUiChartSequence2Minus2TextColor: @sapChart_Sequence_2_Minus2_TextColor;
@sapUiChartSequence2Minus2TextShadow: @sapChart_Sequence_2_Minus2_TextShadow;
@sapUiChartSequence2Minus3: @sapChart_Sequence_2_Minus3;
@sapUiChartSequence2Minus3TextColor: @sapChart_Sequence_2_Minus3_TextColor;
@sapUiChartSequence2Minus3TextShadow: @sapChart_Sequence_2_Minus3_TextShadow;
@sapUiChartSequence2Minus4: @sapChart_Sequence_2_Minus4;
@sapUiChartSequence2Minus4TextColor: @sapChart_Sequence_2_Minus4_TextColor;
@sapUiChartSequence2Minus4TextShadow: @sapChart_Sequence_2_Minus4_TextShadow;
@sapUiChartSequence2Minus5: @sapChart_Sequence_2_Minus5;
@sapUiChartSequence2Minus5TextColor: @sapChart_Sequence_2_Minus5_TextColor;
@sapUiChartSequence2Minus5TextShadow: @sapChart_Sequence_2_Minus5_TextShadow;
@sapUiChartSequence3Plus3: @sapChart_Sequence_3_Plus3;
@sapUiChartSequence3Plus3TextColor: @sapChart_Sequence_3_Plus3_TextColor;
@sapUiChartSequence3Plus3TextShadow: @sapChart_Sequence_3_Plus3_TextShadow;
@sapUiChartSequence3Plus2: @sapChart_Sequence_3_Plus2;
@sapUiChartSequence3Plus2TextColor: @sapChart_Sequence_3_Plus2_TextColor;
@sapUiChartSequence3Plus2TextShadow: @sapChart_Sequence_3_Plus2_TextShadow;
@sapUiChartSequence3Plus1: @sapChart_Sequence_3_Plus1;
@sapUiChartSequence3Plus1TextColor: @sapChart_Sequence_3_Plus1_TextColor;
@sapUiChartSequence3Plus1TextShadow: @sapChart_Sequence_3_Plus1_TextShadow;
@sapUiChartSequence3: @sapChart_Sequence_3;
@sapUiChartSequence3TextColor: @sapChart_Sequence_3_TextColor;
@sapUiChartSequence3TextShadow: @sapChart_Sequence_3_TextShadow;
@sapUiChartSequence3BorderColor: @sapChart_Sequence_3_BorderColor;
@sapUiChartSequence3Minus1: @sapChart_Sequence_3_Minus1;
@sapUiChartSequence3Minus1TextColor: @sapChart_Sequence_3_Minus1_TextColor;
@sapUiChartSequence3Minus1TextShadow: @sapChart_Sequence_3_Minus1_TextShadow;
@sapUiChartSequence3Minus2: @sapChart_Sequence_3_Minus2;
@sapUiChartSequence3Minus2TextColor: @sapChart_Sequence_3_Minus2_TextColor;
@sapUiChartSequence3Minus2TextShadow: @sapChart_Sequence_3_Minus2_TextShadow;
@sapUiChartSequence3Minus3: @sapChart_Sequence_3_Minus3;
@sapUiChartSequence3Minus3TextColor: @sapChart_Sequence_3_Minus3_TextColor;
@sapUiChartSequence3Minus3TextShadow: @sapChart_Sequence_3_Minus3_TextShadow;
@sapUiChartSequence3Minus4: @sapChart_Sequence_3_Minus4;
@sapUiChartSequence3Minus4TextColor: @sapChart_Sequence_3_Minus4_TextColor;
@sapUiChartSequence3Minus4TextShadow: @sapChart_Sequence_3_Minus4_TextShadow;
@sapUiChartSequence3Minus5: @sapChart_Sequence_3_Minus5;
@sapUiChartSequence3Minus5TextColor: @sapChart_Sequence_3_Minus5_TextColor;
@sapUiChartSequence3Minus5TextShadow: @sapChart_Sequence_3_Minus5_TextShadow;
@sapUiChartSequence4Plus3: @sapChart_Sequence_4_Plus3;
@sapUiChartSequence4Plus3TextColor: @sapChart_Sequence_4_Plus3_TextColor;
@sapUiChartSequence4Plus3TextShadow: @sapChart_Sequence_4_Plus3_TextShadow;
@sapUiChartSequence4Plus2: @sapChart_Sequence_4_Plus2;
@sapUiChartSequence4Plus2TextColor: @sapChart_Sequence_4_Plus2_TextColor;
@sapUiChartSequence4Plus2TextShadow: @sapChart_Sequence_4_Plus2_TextShadow;
@sapUiChartSequence4Plus1: @sapChart_Sequence_4_Plus1;
@sapUiChartSequence4Plus1TextColor: @sapChart_Sequence_4_Plus1_TextColor;
@sapUiChartSequence4Plus1TextShadow: @sapChart_Sequence_4_Plus1_TextShadow;
@sapUiChartSequence4: @sapChart_Sequence_4;
@sapUiChartSequence4TextColor: @sapChart_Sequence_4_TextColor;
@sapUiChartSequence4TextShadow: @sapChart_Sequence_4_TextShadow;
@sapUiChartSequence4BorderColor: @sapChart_Sequence_4_BorderColor;
@sapUiChartSequence4Minus1: @sapChart_Sequence_4_Minus1;
@sapUiChartSequence4Minus1TextColor: @sapChart_Sequence_4_Minus1_TextColor;
@sapUiChartSequence4Minus1TextShadow: @sapChart_Sequence_4_Minus1_TextShadow;
@sapUiChartSequence4Minus2: @sapChart_Sequence_4_Minus2;
@sapUiChartSequence4Minus2TextColor: @sapChart_Sequence_4_Minus2_TextColor;
@sapUiChartSequence4Minus2TextShadow: @sapChart_Sequence_4_Minus2_TextShadow;
@sapUiChartSequence4Minus3: @sapChart_Sequence_4_Minus3;
@sapUiChartSequence4Minus3TextColor: @sapChart_Sequence_4_Minus3_TextColor;
@sapUiChartSequence4Minus3TextShadow: @sapChart_Sequence_4_Minus3_TextShadow;
@sapUiChartSequence4Minus4: @sapChart_Sequence_4_Minus4;
@sapUiChartSequence4Minus4TextColor: @sapChart_Sequence_4_Minus4_TextColor;
@sapUiChartSequence4Minus4TextShadow: @sapChart_Sequence_4_Minus4_TextShadow;
@sapUiChartSequence4Minus5: @sapChart_Sequence_4_Minus5;
@sapUiChartSequence4Minus5TextColor: @sapChart_Sequence_4_Minus5_TextColor;
@sapUiChartSequence4Minus5TextShadow: @sapChart_Sequence_4_Minus5_TextShadow;
@sapUiChartSequence5Plus3: @sapChart_Sequence_5_Plus3;
@sapUiChartSequence5Plus3TextColor: @sapChart_Sequence_5_Plus3_TextColor;
@sapUiChartSequence5Plus3TextShadow: @sapChart_Sequence_5_Plus3_TextShadow;
@sapUiChartSequence5Plus2: @sapChart_Sequence_5_Plus2;
@sapUiChartSequence5Plus2TextColor: @sapChart_Sequence_5_Plus2_TextColor;
@sapUiChartSequence5Plus2TextShadow: @sapChart_Sequence_5_Plus2_TextShadow;
@sapUiChartSequence5Plus1: @sapChart_Sequence_5_Plus1;
@sapUiChartSequence5Plus1TextColor: @sapChart_Sequence_5_Plus1_TextColor;
@sapUiChartSequence5Plus1TextShadow: @sapChart_Sequence_5_Plus1_TextShadow;
@sapUiChartSequence5: @sapChart_Sequence_5;
@sapUiChartSequence5TextColor: @sapChart_Sequence_5_TextColor;
@sapUiChartSequence5TextShadow: @sapChart_Sequence_5_TextShadow;
@sapUiChartSequence5BorderColor: @sapChart_Sequence_5_BorderColor;
@sapUiChartSequence5Minus1: @sapChart_Sequence_5_Minus1;
@sapUiChartSequence5Minus1TextColor: @sapChart_Sequence_5_Minus1_TextColor;
@sapUiChartSequence5Minus1TextShadow: @sapChart_Sequence_5_Minus1_TextShadow;
@sapUiChartSequence5Minus2: @sapChart_Sequence_5_Minus2;
@sapUiChartSequence5Minus2TextColor: @sapChart_Sequence_5_Minus2_TextColor;
@sapUiChartSequence5Minus2TextShadow: @sapChart_Sequence_5_Minus2_TextShadow;
@sapUiChartSequence5Minus3: @sapChart_Sequence_5_Minus3;
@sapUiChartSequence5Minus3TextColor: @sapChart_Sequence_5_Minus3_TextColor;
@sapUiChartSequence5Minus3TextShadow: @sapChart_Sequence_5_Minus3_TextShadow;
@sapUiChartSequence5Minus4: @sapChart_Sequence_5_Minus4;
@sapUiChartSequence5Minus4TextColor: @sapChart_Sequence_5_Minus4_TextColor;
@sapUiChartSequence5Minus4TextShadow: @sapChart_Sequence_5_Minus4_TextShadow;
@sapUiChartSequence5Minus5: @sapChart_Sequence_5_Minus5;
@sapUiChartSequence5Minus5TextColor: @sapChart_Sequence_5_Minus5_TextColor;
@sapUiChartSequence5Minus5TextShadow: @sapChart_Sequence_5_Minus5_TextShadow;
@sapUiChartSequence6Plus3: @sapChart_Sequence_6_Plus3;
@sapUiChartSequence6Plus3TextColor: @sapChart_Sequence_6_Plus3_TextColor;
@sapUiChartSequence6Plus3TextShadow: @sapChart_Sequence_6_Plus3_TextShadow;
@sapUiChartSequence6Plus2: @sapChart_Sequence_6_Plus2;
@sapUiChartSequence6Plus2TextColor: @sapChart_Sequence_6_Plus2_TextColor;
@sapUiChartSequence6Plus2TextShadow: @sapChart_Sequence_6_Plus2_TextShadow;
@sapUiChartSequence6Plus1: @sapChart_Sequence_6_Plus1;
@sapUiChartSequence6Plus1TextColor: @sapChart_Sequence_6_Plus1_TextColor;
@sapUiChartSequence6Plus1TextShadow: @sapChart_Sequence_6_Plus1_TextShadow;
@sapUiChartSequence6: @sapChart_Sequence_6;
@sapUiChartSequence6TextColor: @sapChart_Sequence_6_TextColor;
@sapUiChartSequence6TextShadow: @sapChart_Sequence_6_TextShadow;
@sapUiChartSequence6BorderColor: @sapChart_Sequence_6_BorderColor;
@sapUiChartSequence6Minus1: @sapChart_Sequence_6_Minus1;
@sapUiChartSequence6Minus1TextColor: @sapChart_Sequence_6_Minus1_TextColor;
@sapUiChartSequence6Minus1TextShadow: @sapChart_Sequence_6_Minus1_TextShadow;
@sapUiChartSequence6Minus2: @sapChart_Sequence_6_Minus2;
@sapUiChartSequence6Minus2TextColor: @sapChart_Sequence_6_Minus2_TextColor;
@sapUiChartSequence6Minus2TextShadow: @sapChart_Sequence_6_Minus2_TextShadow;
@sapUiChartSequence6Minus3: @sapChart_Sequence_6_Minus3;
@sapUiChartSequence6Minus3TextColor: @sapChart_Sequence_6_Minus3_TextColor;
@sapUiChartSequence6Minus3TextShadow: @sapChart_Sequence_6_Minus3_TextShadow;
@sapUiChartSequence6Minus4: @sapChart_Sequence_6_Minus4;
@sapUiChartSequence6Minus4TextColor: @sapChart_Sequence_6_Minus4_TextColor;
@sapUiChartSequence6Minus4TextShadow: @sapChart_Sequence_6_Minus4_TextShadow;
@sapUiChartSequence6Minus5: @sapChart_Sequence_6_Minus5;
@sapUiChartSequence6Minus5TextColor: @sapChart_Sequence_6_Minus5_TextColor;
@sapUiChartSequence6Minus5TextShadow: @sapChart_Sequence_6_Minus5_TextShadow;
@sapUiChartSequence7Plus3: @sapChart_Sequence_7_Plus3;
@sapUiChartSequence7Plus3TextColor: @sapChart_Sequence_7_Plus3_TextColor;
@sapUiChartSequence7Plus3TextShadow: @sapChart_Sequence_7_Plus3_TextShadow;
@sapUiChartSequence7Plus2: @sapChart_Sequence_7_Plus2;
@sapUiChartSequence7Plus2TextColor: @sapChart_Sequence_7_Plus2_TextColor;
@sapUiChartSequence7Plus2TextShadow: @sapChart_Sequence_7_Plus2_TextShadow;
@sapUiChartSequence7Plus1: @sapChart_Sequence_7_Plus1;
@sapUiChartSequence7Plus1TextColor: @sapChart_Sequence_7_Plus1_TextColor;
@sapUiChartSequence7Plus1TextShadow: @sapChart_Sequence_7_Plus1_TextShadow;
@sapUiChartSequence7: @sapChart_Sequence_7;
@sapUiChartSequence7TextColor: @sapChart_Sequence_7_TextColor;
@sapUiChartSequence7TextShadow: @sapChart_Sequence_7_TextShadow;
@sapUiChartSequence7BorderColor: @sapChart_Sequence_7_BorderColor;
@sapUiChartSequence7Minus1: @sapChart_Sequence_7_Minus1;
@sapUiChartSequence7Minus1TextColor: @sapChart_Sequence_7_Minus1_TextColor;
@sapUiChartSequence7Minus1TextShadow: @sapChart_Sequence_7_Minus1_TextShadow;
@sapUiChartSequence7Minus2: @sapChart_Sequence_7_Minus2;
@sapUiChartSequence7Minus2TextColor: @sapChart_Sequence_7_Minus2_TextColor;
@sapUiChartSequence7Minus2TextShadow: @sapChart_Sequence_7_Minus2_TextShadow;
@sapUiChartSequence7Minus3: @sapChart_Sequence_7_Minus3;
@sapUiChartSequence7Minus3TextColor: @sapChart_Sequence_7_Minus3_TextColor;
@sapUiChartSequence7Minus3TextShadow: @sapChart_Sequence_7_Minus3_TextShadow;
@sapUiChartSequence7Minus4: @sapChart_Sequence_7_Minus4;
@sapUiChartSequence7Minus4TextColor: @sapChart_Sequence_7_Minus4_TextColor;
@sapUiChartSequence7Minus4TextShadow: @sapChart_Sequence_7_Minus4_TextShadow;
@sapUiChartSequence7Minus5: @sapChart_Sequence_7_Minus5;
@sapUiChartSequence7Minus5TextColor: @sapChart_Sequence_7_Minus5_TextColor;
@sapUiChartSequence7Minus5TextShadow: @sapChart_Sequence_7_Minus5_TextShadow;
@sapUiChartSequence8Plus3: @sapChart_Sequence_8_Plus3;
@sapUiChartSequence8Plus3TextColor: @sapChart_Sequence_8_Plus3_TextColor;
@sapUiChartSequence8Plus3TextShadow: @sapChart_Sequence_8_Plus3_TextShadow;
@sapUiChartSequence8Plus2: @sapChart_Sequence_8_Plus2;
@sapUiChartSequence8Plus2TextColor: @sapChart_Sequence_8_Plus2_TextColor;
@sapUiChartSequence8Plus2TextShadow: @sapChart_Sequence_8_Plus2_TextShadow;
@sapUiChartSequence8Plus1: @sapChart_Sequence_8_Plus1;
@sapUiChartSequence8Plus1TextColor: @sapChart_Sequence_8_Plus1_TextColor;
@sapUiChartSequence8Plus1TextShadow: @sapChart_Sequence_8_Plus1_TextShadow;
@sapUiChartSequence8: @sapChart_Sequence_8;
@sapUiChartSequence8TextColor: @sapChart_Sequence_8_TextColor;
@sapUiChartSequence8TextShadow: @sapChart_Sequence_8_TextShadow;
@sapUiChartSequence8BorderColor: @sapChart_Sequence_8_BorderColor;
@sapUiChartSequence8Minus1: @sapChart_Sequence_8_Minus1;
@sapUiChartSequence8Minus1TextColor: @sapChart_Sequence_8_Minus1_TextColor;
@sapUiChartSequence8Minus1TextShadow: @sapChart_Sequence_8_Minus1_TextShadow;
@sapUiChartSequence8Minus2: @sapChart_Sequence_8_Minus2;
@sapUiChartSequence8Minus2TextColor: @sapChart_Sequence_8_Minus2_TextColor;
@sapUiChartSequence8Minus2TextShadow: @sapChart_Sequence_8_Minus2_TextShadow;
@sapUiChartSequence8Minus3: @sapChart_Sequence_8_Minus3;
@sapUiChartSequence8Minus3TextColor: @sapChart_Sequence_8_Minus3_TextColor;
@sapUiChartSequence8Minus3TextShadow: @sapChart_Sequence_8_Minus3_TextShadow;
@sapUiChartSequence8Minus4: @sapChart_Sequence_8_Minus4;
@sapUiChartSequence8Minus4TextColor: @sapChart_Sequence_8_Minus4_TextColor;
@sapUiChartSequence8Minus4TextShadow: @sapChart_Sequence_8_Minus4_TextShadow;
@sapUiChartSequence8Minus5: @sapChart_Sequence_8_Minus5;
@sapUiChartSequence8Minus5TextColor: @sapChart_Sequence_8_Minus5_TextColor;
@sapUiChartSequence8Minus5TextShadow: @sapChart_Sequence_8_Minus5_TextShadow;
@sapUiChartSequence9Plus3: @sapChart_Sequence_9_Plus3;
@sapUiChartSequence9Plus3TextColor: @sapChart_Sequence_9_Plus3_TextColor;
@sapUiChartSequence9Plus3TextShadow: @sapChart_Sequence_9_Plus3_TextShadow;
@sapUiChartSequence9Plus2: @sapChart_Sequence_9_Plus2;
@sapUiChartSequence9Plus2TextColor: @sapChart_Sequence_9_Plus2_TextColor;
@sapUiChartSequence9Plus2TextShadow: @sapChart_Sequence_9_Plus2_TextShadow;
@sapUiChartSequence9Plus1: @sapChart_Sequence_9_Plus1;
@sapUiChartSequence9Plus1TextColor: @sapChart_Sequence_9_Plus1_TextColor;
@sapUiChartSequence9Plus1TextShadow: @sapChart_Sequence_9_Plus1_TextShadow;
@sapUiChartSequence9: @sapChart_Sequence_9;
@sapUiChartSequence9TextColor: @sapChart_Sequence_9_TextColor;
@sapUiChartSequence9TextShadow: @sapChart_Sequence_9_TextShadow;
@sapUiChartSequence9BorderColor: @sapChart_Sequence_9_BorderColor;
@sapUiChartSequence9Minus1: @sapChart_Sequence_9_Minus1;
@sapUiChartSequence9Minus1TextColor: @sapChart_Sequence_9_Minus1_TextColor;
@sapUiChartSequence9Minus1TextShadow: @sapChart_Sequence_9_Minus1_TextShadow;
@sapUiChartSequence9Minus2: @sapChart_Sequence_9_Minus2;
@sapUiChartSequence9Minus2TextColor: @sapChart_Sequence_9_Minus2_TextColor;
@sapUiChartSequence9Minus2TextShadow: @sapChart_Sequence_9_Minus2_TextShadow;
@sapUiChartSequence9Minus3: @sapChart_Sequence_9_Minus3;
@sapUiChartSequence9Minus3TextColor: @sapChart_Sequence_9_Minus3_TextColor;
@sapUiChartSequence9Minus3TextShadow: @sapChart_Sequence_9_Minus3_TextShadow;
@sapUiChartSequence9Minus4: @sapChart_Sequence_9_Minus4;
@sapUiChartSequence9Minus4TextColor: @sapChart_Sequence_9_Minus4_TextColor;
@sapUiChartSequence9Minus4TextShadow: @sapChart_Sequence_9_Minus4_TextShadow;
@sapUiChartSequence9Minus5: @sapChart_Sequence_9_Minus5;
@sapUiChartSequence9Minus5TextColor: @sapChart_Sequence_9_Minus5_TextColor;
@sapUiChartSequence9Minus5TextShadow: @sapChart_Sequence_9_Minus5_TextShadow;
@sapUiChartSequence10Plus3: @sapChart_Sequence_10_Plus3;
@sapUiChartSequence10Plus3TextColor: @sapChart_Sequence_10_Plus3_TextColor;
@sapUiChartSequence10Plus3TextShadow: @sapChart_Sequence_10_Plus3_TextShadow;
@sapUiChartSequence10Plus2: @sapChart_Sequence_10_Plus2;
@sapUiChartSequence10Plus2TextColor: @sapChart_Sequence_10_Plus2_TextColor;
@sapUiChartSequence10Plus2TextShadow: @sapChart_Sequence_10_Plus2_TextShadow;
@sapUiChartSequence10Plus1: @sapChart_Sequence_10_Plus1;
@sapUiChartSequence10Plus1TextColor: @sapChart_Sequence_10_Plus1_TextColor;
@sapUiChartSequence10Plus1TextShadow: @sapChart_Sequence_10_Plus1_TextShadow;
@sapUiChartSequence10: @sapChart_Sequence_10;
@sapUiChartSequence10TextColor: @sapChart_Sequence_10_TextColor;
@sapUiChartSequence10TextShadow: @sapChart_Sequence_10_TextShadow;
@sapUiChartSequence10BorderColor: @sapChart_Sequence_10_BorderColor;
@sapUiChartSequence10Minus1: @sapChart_Sequence_10_Minus1;
@sapUiChartSequence10Minus1TextColor: @sapChart_Sequence_10_Minus1_TextColor;
@sapUiChartSequence10Minus1TextShadow: @sapChart_Sequence_10_Minus1_TextShadow;
@sapUiChartSequence10Minus2: @sapChart_Sequence_10_Minus2;
@sapUiChartSequence10Minus2TextColor: @sapChart_Sequence_10_Minus2_TextColor;
@sapUiChartSequence10Minus2TextShadow: @sapChart_Sequence_10_Minus2_TextShadow;
@sapUiChartSequence10Minus3: @sapChart_Sequence_10_Minus3;
@sapUiChartSequence10Minus3TextColor: @sapChart_Sequence_10_Minus3_TextColor;
@sapUiChartSequence10Minus3TextShadow: @sapChart_Sequence_10_Minus3_TextShadow;
@sapUiChartSequence10Minus4: @sapChart_Sequence_10_Minus4;
@sapUiChartSequence10Minus4TextColor: @sapChart_Sequence_10_Minus4_TextColor;
@sapUiChartSequence10Minus4TextShadow: @sapChart_Sequence_10_Minus4_TextShadow;
@sapUiChartSequence10Minus5: @sapChart_Sequence_10_Minus5;
@sapUiChartSequence10Minus5TextColor: @sapChart_Sequence_10_Minus5_TextColor;
@sapUiChartSequence10Minus5TextShadow: @sapChart_Sequence_10_Minus5_TextShadow;
@sapUiChartSequence11Plus3: @sapChart_Sequence_11_Plus3;
@sapUiChartSequence11Plus3TextColor: @sapChart_Sequence_11_Plus3_TextColor;
@sapUiChartSequence11Plus3TextShadow: @sapChart_Sequence_11_Plus3_TextShadow;
@sapUiChartSequence11Plus2: @sapChart_Sequence_11_Plus2;
@sapUiChartSequence11Plus2TextColor: @sapChart_Sequence_11_Plus2_TextColor;
@sapUiChartSequence11Plus2TextShadow: @sapChart_Sequence_11_Plus2_TextShadow;
@sapUiChartSequence11Plus1: @sapChart_Sequence_11_Plus1;
@sapUiChartSequence11Plus1TextColor: @sapChart_Sequence_11_Plus1_TextColor;
@sapUiChartSequence11Plus1TextShadow: @sapChart_Sequence_11_Plus1_TextShadow;
@sapUiChartSequence11: @sapChart_Sequence_11;
@sapUiChartSequence11TextColor: @sapChart_Sequence_11_TextColor;
@sapUiChartSequence11TextShadow: @sapChart_Sequence_11_TextShadow;
@sapUiChartSequence11BorderColor: @sapChart_Sequence_11_BorderColor;
@sapUiChartSequence11Minus1: @sapChart_Sequence_11_Minus1;
@sapUiChartSequence11Minus1TextColor: @sapChart_Sequence_11_Minus1_TextColor;
@sapUiChartSequence11Minus1TextShadow: @sapChart_Sequence_11_Minus1_TextShadow;
@sapUiChartSequence11Minus2: @sapChart_Sequence_11_Minus2;
@sapUiChartSequence11Minus2TextColor: @sapChart_Sequence_11_Minus2_TextColor;
@sapUiChartSequence11Minus2TextShadow: @sapChart_Sequence_11_Minus2_TextShadow;
@sapUiChartSequence11Minus3: @sapChart_Sequence_11_Minus3;
@sapUiChartSequence11Minus3TextColor: @sapChart_Sequence_11_Minus3_TextColor;
@sapUiChartSequence11Minus3TextShadow: @sapChart_Sequence_11_Minus3_TextShadow;
@sapUiChartSequence11Minus4: @sapChart_Sequence_11_Minus4;
@sapUiChartSequence11Minus4TextColor: @sapChart_Sequence_11_Minus4_TextColor;
@sapUiChartSequence11Minus4TextShadow: @sapChart_Sequence_11_Minus4_TextShadow;
@sapUiChartSequence11Minus5: @sapChart_Sequence_11_Minus5;
@sapUiChartSequence11Minus5TextColor: @sapChart_Sequence_11_Minus5_TextColor;
@sapUiChartSequence11Minus5TextShadow: @sapChart_Sequence_11_Minus5_TextShadow;
@sapUiChartSequence12Plus3: @sapChart_Sequence_12_Plus3;
@sapUiChartSequence12Plus3TextColor: @sapChart_Sequence_12_Plus3_TextColor;
@sapUiChartSequence12Plus3TextShadow: @sapChart_Sequence_12_Plus3_TextShadow;
@sapUiChartSequence12Plus2: @sapChart_Sequence_12_Plus2;
@sapUiChartSequence12Plus2TextColor: @sapChart_Sequence_12_Plus2_TextColor;
@sapUiChartSequence12Plus2TextShadow: @sapChart_Sequence_12_Plus2_TextShadow;
@sapUiChartSequence12Plus1: @sapChart_Sequence_12_Plus1;
@sapUiChartSequence12Plus1TextColor: @sapChart_Sequence_12_Plus1_TextColor;
@sapUiChartSequence12Plus1TextShadow: @sapChart_Sequence_12_Plus1_TextShadow;
@sapUiChartSequence12: @sapChart_Sequence_12;
@sapUiChartSequence12TextColor: @sapChart_Sequence_12_TextColor;
@sapUiChartSequence12TextShadow: @sapChart_Sequence_12_TextShadow;
@sapUiChartSequence12BorderColor: @sapChart_Sequence_12_BorderColor;
@sapUiChartSequence12Minus1: @sapChart_Sequence_12_Minus1;
@sapUiChartSequence12Minus1TextColor: @sapChart_Sequence_12_Minus1_TextColor;
@sapUiChartSequence12Minus1TextShadow: @sapChart_Sequence_12_Minus1_TextShadow;
@sapUiChartSequence12Minus2: @sapChart_Sequence_12_Minus2;
@sapUiChartSequence12Minus2TextColor: @sapChart_Sequence_12_Minus2_TextColor;
@sapUiChartSequence12Minus2TextShadow: @sapChart_Sequence_12_Minus2_TextShadow;
@sapUiChartSequence12Minus3: @sapChart_Sequence_12_Minus3;
@sapUiChartSequence12Minus3TextColor: @sapChart_Sequence_12_Minus3_TextColor;
@sapUiChartSequence12Minus3TextShadow: @sapChart_Sequence_12_Minus3_TextShadow;
@sapUiChartSequence12Minus4: @sapChart_Sequence_12_Minus4;
@sapUiChartSequence12Minus4TextColor: @sapChart_Sequence_12_Minus4_TextColor;
@sapUiChartSequence12Minus4TextShadow: @sapChart_Sequence_12_Minus4_TextShadow;
@sapUiChartSequence12Minus5: @sapChart_Sequence_12_Minus5;
@sapUiChartSequence12Minus5TextColor: @sapChart_Sequence_12_Minus5_TextColor;
@sapUiChartSequence12Minus5TextShadow: @sapChart_Sequence_12_Minus5_TextShadow;

@sapUiChartSequenceBadPlus3: @sapChart_Sequence_Bad_Plus3;
@sapUiChartSequenceBadPlus3TextColor: @sapChart_Sequence_Bad_Plus3_TextColor;
@sapUiChartSequenceBadPlus3TextShadow: @sapChart_Sequence_Bad_Plus3_TextShadow;
@sapUiChartSequenceBadPlus2: @sapChart_Sequence_Bad_Plus2;
@sapUiChartSequenceBadPlus2TextColor: @sapChart_Sequence_Bad_Plus2_TextColor;
@sapUiChartSequenceBadPlus2TextShadow: @sapChart_Sequence_Bad_Plus2_TextShadow;
@sapUiChartSequenceBadPlus1: @sapChart_Sequence_Bad_Plus1;
@sapUiChartSequenceBadPlus1TextColor: @sapChart_Sequence_Bad_Plus1_TextColor;
@sapUiChartSequenceBadPlus1TextShadow: @sapChart_Sequence_Bad_Plus1_TextShadow;
@sapUiChartSequenceBad: @sapChart_Sequence_Bad;
@sapUiChartSequenceBadTextColor: @sapChart_Sequence_Bad_TextColor;
@sapUiChartSequenceBadTextShadow: @sapChart_Sequence_Bad_TextShadow;
@sapUiChartSequenceBadBorderColor: @sapChart_Sequence_Bad_BorderColor;
@sapUiChartSequenceBadMinus1: @sapChart_Sequence_Bad_Minus1;
@sapUiChartSequenceBadMinus1TextColor: @sapChart_Sequence_Bad_Minus1_TextColor;
@sapUiChartSequenceBadMinus1TextShadow: @sapChart_Sequence_Bad_Minus1_TextShadow;
@sapUiChartSequenceBadMinus2: @sapChart_Sequence_Bad_Minus2;
@sapUiChartSequenceBadMinus2TextColor: @sapChart_Sequence_Bad_Minus2_TextColor;
@sapUiChartSequenceBadMinus2TextShadow: @sapChart_Sequence_Bad_Minus2_TextShadow;
@sapUiChartSequenceBadMinus3: @sapChart_Sequence_Bad_Minus3;
@sapUiChartSequenceBadMinus3TextColor: @sapChart_Sequence_Bad_Minus3_TextColor;
@sapUiChartSequenceBadMinus3TextShadow: @sapChart_Sequence_Bad_Minus3_TextShadow;
@sapUiChartSequenceBadMinus4: @sapChart_Sequence_Bad_Minus4;
@sapUiChartSequenceBadMinus4TextColor: @sapChart_Sequence_Bad_Minus4_TextColor;
@sapUiChartSequenceBadMinus4TextShadow: @sapChart_Sequence_Bad_Minus4_TextShadow;
@sapUiChartSequenceBadMinus5: @sapChart_Sequence_Bad_Minus5;
@sapUiChartSequenceBadMinus5TextColor: @sapChart_Sequence_Bad_Minus5_TextColor;
@sapUiChartSequenceBadMinus5TextShadow: @sapChart_Sequence_Bad_Minus5_TextShadow;
@sapUiChartSequenceCriticalPlus3: @sapChart_Sequence_Critical_Plus3;
@sapUiChartSequenceCriticalPlus3TextColor: @sapChart_Sequence_Critical_Plus3_TextColor;
@sapUiChartSequenceCriticalPlus3TextShadow: @sapChart_Sequence_Critical_Plus3_TextShadow;
@sapUiChartSequenceCriticalPlus2: @sapChart_Sequence_Critical_Plus2;
@sapUiChartSequenceCriticalPlus2TextColor: @sapChart_Sequence_Critical_Plus2_TextColor;
@sapUiChartSequenceCriticalPlus2TextShadow: @sapChart_Sequence_Critical_Plus2_TextShadow;
@sapUiChartSequenceCriticalPlus1: @sapChart_Sequence_Critical_Plus1;
@sapUiChartSequenceCriticalPlus1TextColor: @sapChart_Sequence_Critical_Plus1_TextColor;
@sapUiChartSequenceCriticalPlus1TextShadow: @sapChart_Sequence_Critical_Plus1_TextShadow;
@sapUiChartSequenceCritical: @sapChart_Sequence_Critical;
@sapUiChartSequenceCriticalTextColor: @sapChart_Sequence_Critical_TextColor;
@sapUiChartSequenceCriticalTextShadow: @sapChart_Sequence_Critical_TextShadow;
@sapUiChartSequenceCriticalBorderColor: @sapChart_Sequence_Critical_BorderColor;
@sapUiChartSequenceCriticalMinus1: @sapChart_Sequence_Critical_Minus1;
@sapUiChartSequenceCriticalMinus1TextColor: @sapChart_Sequence_Critical_Minus1_TextColor;
@sapUiChartSequenceCriticalMinus1TextShadow: @sapChart_Sequence_Critical_Minus1_TextShadow;
@sapUiChartSequenceCriticalMinus2: @sapChart_Sequence_Critical_Minus2;
@sapUiChartSequenceCriticalMinus2TextColor: @sapChart_Sequence_Critical_Minus2_TextColor;
@sapUiChartSequenceCriticalMinus2TextShadow: @sapChart_Sequence_Critical_Minus2_TextShadow;
@sapUiChartSequenceCriticalMinus3: @sapChart_Sequence_Critical_Minus3;
@sapUiChartSequenceCriticalMinus3TextColor: @sapChart_Sequence_Critical_Minus3_TextColor;
@sapUiChartSequenceCriticalMinus3TextShadow: @sapChart_Sequence_Critical_Minus3_TextShadow;
@sapUiChartSequenceCriticalMinus4: @sapChart_Sequence_Critical_Minus4;
@sapUiChartSequenceCriticalMinus4TextColor: @sapChart_Sequence_Critical_Minus4_TextColor;
@sapUiChartSequenceCriticalMinus4TextShadow: @sapChart_Sequence_Critical_Minus4_TextShadow;
@sapUiChartSequenceCriticalMinus5: @sapChart_Sequence_Critical_Minus5;
@sapUiChartSequenceCriticalMinus5TextColor: @sapChart_Sequence_Critical_Minus5_TextColor;
@sapUiChartSequenceCriticalMinus5TextShadow: @sapChart_Sequence_Critical_Minus5_TextShadow;
@sapUiChartSequenceGoodPlus3: @sapChart_Sequence_Good_Plus3;
@sapUiChartSequenceGoodPlus3TextColor: @sapChart_Sequence_Good_Plus3_TextColor;
@sapUiChartSequenceGoodPlus3TextShadow: @sapChart_Sequence_Good_Plus3_TextShadow;
@sapUiChartSequenceGoodPlus2: @sapChart_Sequence_Good_Plus2;
@sapUiChartSequenceGoodPlus2TextColor: @sapChart_Sequence_Good_Plus2_TextColor;
@sapUiChartSequenceGoodPlus2TextShadow: @sapChart_Sequence_Good_Plus2_TextShadow;
@sapUiChartSequenceGoodPlus1: @sapChart_Sequence_Good_Plus1;
@sapUiChartSequenceGoodPlus1TextColor: @sapChart_Sequence_Good_Plus1_TextColor;
@sapUiChartSequenceGoodPlus1TextShadow: @sapChart_Sequence_Good_Plus1_TextShadow;
@sapUiChartSequenceGood: @sapChart_Sequence_Good;
@sapUiChartSequenceGoodTextColor: @sapChart_Sequence_Good_TextColor;
@sapUiChartSequenceGoodTextShadow: @sapChart_Sequence_Good_TextShadow;
@sapUiChartSequenceGoodBorderColor: @sapChart_Sequence_Good_BorderColor;
@sapUiChartSequenceGoodMinus1: @sapChart_Sequence_Good_Minus1;
@sapUiChartSequenceGoodMinus1TextColor: @sapChart_Sequence_Good_Minus1_TextColor;
@sapUiChartSequenceGoodMinus1TextShadow: @sapChart_Sequence_Good_Minus1_TextShadow;
@sapUiChartSequenceGoodMinus2: @sapChart_Sequence_Good_Minus2;
@sapUiChartSequenceGoodMinus2TextColor: @sapChart_Sequence_Good_Minus2_TextColor;
@sapUiChartSequenceGoodMinus2TextShadow: @sapChart_Sequence_Good_Minus2_TextShadow;
@sapUiChartSequenceGoodMinus3: @sapChart_Sequence_Good_Minus3;
@sapUiChartSequenceGoodMinus3TextColor: @sapChart_Sequence_Good_Minus3_TextColor;
@sapUiChartSequenceGoodMinus3TextShadow: @sapChart_Sequence_Good_Minus3_TextShadow;
@sapUiChartSequenceGoodMinus4: @sapChart_Sequence_Good_Minus4;
@sapUiChartSequenceGoodMinus4TextColor: @sapChart_Sequence_Good_Minus4_TextColor;
@sapUiChartSequenceGoodMinus4TextShadow: @sapChart_Sequence_Good_Minus4_TextShadow;
@sapUiChartSequenceGoodMinus5: @sapChart_Sequence_Good_Minus5;
@sapUiChartSequenceGoodMinus5TextColor: @sapChart_Sequence_Good_Minus5_TextColor;
@sapUiChartSequenceGoodMinus5TextShadow: @sapChart_Sequence_Good_Minus5_TextShadow;
@sapUiChartSequenceNeutralPlus3: @sapChart_Sequence_Neutral_Plus3;
@sapUiChartSequenceNeutralPlus3TextColor: @sapChart_Sequence_Neutral_Plus3_TextColor;
@sapUiChartSequenceNeutralPlus3TextShadow: @sapChart_Sequence_Neutral_Plus3_TextShadow;
@sapUiChartSequenceNeutralPlus2: @sapChart_Sequence_Neutral_Plus2;
@sapUiChartSequenceNeutralPlus2TextColor: @sapChart_Sequence_Neutral_Plus2_TextColor;
@sapUiChartSequenceNeutralPlus2TextShadow: @sapChart_Sequence_Neutral_Plus2_TextShadow;
@sapUiChartSequenceNeutralPlus1: @sapChart_Sequence_Neutral_Plus1;
@sapUiChartSequenceNeutralPlus1TextColor: @sapChart_Sequence_Neutral_Plus1_TextColor;
@sapUiChartSequenceNeutralPlus1TextShadow: @sapChart_Sequence_Neutral_Plus1_TextShadow;
@sapUiChartSequenceNeutral: @sapChart_Sequence_Neutral;
@sapUiChartSequenceNeutralTextColor: @sapChart_Sequence_Neutral_TextColor;
@sapUiChartSequenceNeutralTextShadow: @sapChart_Sequence_Neutral_TextShadow;
@sapUiChartSequenceNeutralBorderColor: @sapChart_Sequence_Neutral_BorderColor;
@sapUiChartSequenceNeutralMinus1: @sapChart_Sequence_Neutral_Minus1;
@sapUiChartSequenceNeutralMinus1TextColor: @sapChart_Sequence_Neutral_Minus1_TextColor;
@sapUiChartSequenceNeutralMinus1TextShadow: @sapChart_Sequence_Neutral_Minus1_TextShadow;
@sapUiChartSequenceNeutralMinus2: @sapChart_Sequence_Neutral_Minus2;
@sapUiChartSequenceNeutralMinus2TextColor: @sapChart_Sequence_Neutral_Minus2_TextColor;
@sapUiChartSequenceNeutralMinus2TextShadow: @sapChart_Sequence_Neutral_Minus2_TextShadow;
@sapUiChartSequenceNeutralMinus3: @sapChart_Sequence_Neutral_Minus3;
@sapUiChartSequenceNeutralMinus3TextColor: @sapChart_Sequence_Neutral_Minus3_TextColor;
@sapUiChartSequenceNeutralMinus3TextShadow: @sapChart_Sequence_Neutral_Minus3_TextShadow;
@sapUiChartSequenceNeutralMinus4: @sapChart_Sequence_Neutral_Minus4;
@sapUiChartSequenceNeutralMinus4TextColor: @sapChart_Sequence_Neutral_Minus4_TextColor;
@sapUiChartSequenceNeutralMinus4TextShadow: @sapChart_Sequence_Neutral_Minus4_TextShadow;
@sapUiChartSequenceNeutralMinus5: @sapChart_Sequence_Neutral_Minus5;
@sapUiChartSequenceNeutralMinus5TextColor: @sapChart_Sequence_Neutral_Minus5_TextColor;
@sapUiChartSequenceNeutralMinus5TextShadow: @sapChart_Sequence_Neutral_Minus5_TextShadow;


// ============================================
// UX Reference Set - do not use in Controls!!
// ============================================

// =====================================
// Primary Colors
// =====================================

@sapUiPrimary1: @sapPrimary1;
@sapUiPrimary2: @sapPrimary2;
@sapUiPrimary3: @sapPrimary3;
@sapUiPrimary4: @sapPrimary4;
@sapUiPrimary5: @sapPrimary5;
@sapUiPrimary6: @sapPrimary6;
@sapUiPrimary7: @sapPrimary7;


@sapUiShellBackgroundPatternColor: @sapShell_BackgroundPatternColor;
@sapUiShellBackgroundGradient: @sapShell_BackgroundGradient;

@sapUiListHighlightColor: @sapList_HighlightColor;

@sapUiBreakpointSMin: @sapBreakpoint_S_Min;
@sapUiBreakpointMMin: @sapBreakpoint_M_Min;
@sapUiBreakpointLMin: @sapBreakpoint_L_Min;
@sapUiBreakpointXLMin: @sapBreakpoint_XL_Min;

@sapUiSapThemeId: @sapSapThemeId;


// =====================================
// Font
// =====================================

@sapUiFontCondensedFamily: "72 Condensed", 'Arial Narrow', HelveticaNeue-CondensedBold, Arial, sans-serif;

@sapUiFontHeaderWeight: normal;

@sapMFontMediumSize: @sapFontSize;

@sapUiTranslucentBGOpacity: 0;

@sapMPlatformDependent: false;

@sapUiColumnHeaderFontSize: @sapMFontMediumSize;
@sapUiColumnHeaderFontWeight: normal;


// =====================================
// Desktop (sap.ui.commons)
// =====================================

@sapUiDesktopFontFamily: @sapUiFontFamily;

@sapUiDesktopFontSize: 12px;


// use these for desktop controls only
@sapUiFontLargeSize: 13px;
@sapUiFontSmallSize: 11px;
@sapUiFontHeader1Size: 26px;
@sapUiFontHeader2Size: 20px;
@sapUiFontHeader3Size: 18px;
@sapUiFontHeader4Size: 16px;
@sapUiFontHeader5Size: 14px;
@sapUiFontHeader6Size: @sapUiFontLargeSize;

@sapUiLineHeight: 18px;


// ===============================================
// SOME important control-specific parameters...
// Derived from Expert Theming
// (these Parameters should be linked in controls)
// ===============================================

// Derived Chart Colors

@sapUiChartLabelHoverColor: @sapUiButtonHoverBackground;            // #ebebeb
@sapUiChartLabelPressedColor: darken(@sapUiButtonBackground, 17);   // #cccccc
@sapUiChartCategoryAxisLabelFontColor: @sapUiContentForegroundTextColor;    // #333333
@sapUiChartValueAxisLabelFontColor: @sapUiContentLabelColor;
@sapUiChartCategoryAxisLabelFontSize: @sapMFontSmallSize;           // 12px
@sapUiChartValueAxisLabelFontSize: @sapMFontSmallSize;              // 12px
@sapUiChartCategoryAxisLineColor: darken(@sapUiChartGridlineColor, 10);  // #cccccc
@sapUiChartValueAxisLineColor: darken(@sapUiChartGridlineColor, 10);  // #cccccc
@sapUiChartCategoryAxisTickColor: darken(@sapUiChartGridlineColor, 10);  // #cccccc
@sapUiChartValueAxisTickColor: darken(@sapUiChartGridlineColor, 10);   // #cccccc
@sapUiChartBackgroundColor: transparent;
@sapUiChartLabelFontWeight: normal;
@sapUiChartLegendLabelFontColor: @sapUiContentForegroundTextColor;  // #333333
@sapUiChartLegendTitleFontColor: @sapUiGroupTitleTextColor;         // #333333
@sapUiChartLegendTitleFontSize: @sapMFontMediumSize;                // 14px
@sapUiChartLegendLabelFontSize: @sapMFontSmallSize;                 // 12px
@sapUiChartPaletteUndefinedColor: darken(@sapUiBaseText, 20);       // #000000
@sapUiChartGridlineColor: lighten(@sapUiContentForegroundBorderColor, 15);  // #e5e5e5
@sapUiChartReferenceLineColor: darken(@sapUiChartGridlineColor, 70);   // #333333
@sapUiChartDataLabelFontColor: darken(@sapUiBaseText, 20);          // #000000
@sapUiChartReferenceLineLabelColor: @sapUiContentContrastTextColor; // #ffffff
@sapUiChartDataLabelFontSize: @sapMFontSmallSize;                   // 12px
@sapUiChartPopoverDataItemFontColor: darken(@sapUiBaseText, 20);    // #000000
@sapUiChartPopoverGroupFontColor: @sapUiContentForegroundTextColor; // #333333
@sapUiChartPopoverDataItemFontSize: @sapMFontMediumSize;            // 14px
@sapUiChartPopoverGroupFontSize: @sapMFontMediumSize;               // 14px
@sapUiChartPopoverGroupFontWeight: bold;
@sapUiChartScrollBarThumbColor: @sapUiScrollBarFaceColor;           // #b2b2b2
@sapUiChartScrollBarTrackColor: @sapUiScrollBarTrackColor;          // #ffffff
@sapUiChartScrollBarThumbHoverColor: @sapUiScrollBarHoverFaceColor; // #ababab
@sapUiChartMainTitleFontColor: @sapUiGroupTitleTextColor;           // #333333
@sapUiChartAxisTitleFontColor: @sapUiGroupTitleTextColor;           // #333333
@sapUiChartMainTitleFontSize: @sapMFontLargeSize;                   // 16px
@sapUiChartAxisTitleFontSize: @sapMFontSmallSize;                   // 12px
@sapUiChartTitleFontWeight: bold;
@sapUiChartAxisTitleFontWeight: regular;
@sapUiChartLightText: @sapUiContentLabelColor;
@sapUiChartZeroAxisColor: darken(@sapUiChartGridlineColor, 50);     // #666666

@sapUiChartDataPointBorderColor: lighten(@sapUiGroupContentBackground, 2);  // #ffffff
@sapUiChartDataPointBorderHoverSelectedColor: darken(@sapUiChartGridlineColor, 50);  // #666666
@sapUiChartDataPointNotSelectedBackgroundOpacity: 0.6;

@sapUiChartValueAxisLineOpacity: 0;
@sapUiChartCategoryAxisLabelFontHoverColor: @sapUiContentForegroundTextColor;  // #333333
@sapUiChartCategoryAxisLabelFontPressedColor: @sapUiContentForegroundTextColor;  // #333333

@sapUiChartTargetColor: darken(@sapUiChartGridlineColor, 70);       // #333333
@sapUiChartTargetShadowColor: @sapUiContentContrastShadowColor;     // #ffffff
@sapUiChartBubbleBGOpacity: 0.8;

@sapUiChartScrollbarBorderColor: lighten(@sapUiScrollBarBorderColor, 25);  // #f2f2f2
@sapUiChartScrollbarBorderSize: 0;
@sapUiChartScrollbarThumbPadding: 0;

@sapUiChartNegativeLargeText: @sapUiChartBad;  //#dc0d0e
@sapUiChartCriticalLargeText: @sapUiChartCritical;  // #de890d
@sapUiChartPositiveLargeText: @sapUiChartGood;  // #3fa45b
@sapUiChartNeutralLargeText: saturate(darken(@sapUiChartNeutral, 10), 1);  // #69767c

@sapUiChartDataPointBG: saturate(lighten(@sapUiChartNeutral, 30), 1);  // #d5dadc
@sapUiChartDataPointBGBorderColor: saturate(lighten(@sapUiChartNeutral, 30), 1);  // #d5dadc
@sapUiChartDataLineColorWithBG: darken(@sapUiChartGridlineColor, 70);   // #333333
@sapUiChartDataLineColor: darken(@sapUiChartGridlineColor, 70);   // #333333

@sapUiChartRadialRemainingCircle: lighten(@sapUiChartNeutral, 35);  // #e3e6e7
@sapUiChartRadialRemainingCircleBorderColor: lighten(@sapUiChartNeutral, 35);  // #e3e6e7
@sapUiChartRadialBG: lighten(@sapUiGroupContentBackground, 2);  // #ffffff

@sapUiChartLegendHoverBackground: @sapUiListHoverBackground;  // #f0f0f0
@sapUiChartLegendSelectionBackground: @sapUiListSelectionBackgroundColor;  // #e8eff6
@sapUiChartLegendSelectionHoverBackground: @sapUiListSelectionHoverBackground;  // #dde8f1


// qualitative palette

@sapUiChartPaletteQualitativeHue1: @sapUiChart1;
@sapUiChartPaletteQualitativeHue2: @sapUiChart2;
@sapUiChartPaletteQualitativeHue3: @sapUiChart3;
@sapUiChartPaletteQualitativeHue4: @sapUiChart4;
@sapUiChartPaletteQualitativeHue5: @sapUiChart5;
@sapUiChartPaletteQualitativeHue6: @sapUiChart6;
@sapUiChartPaletteQualitativeHue7: @sapUiChart7;
@sapUiChartPaletteQualitativeHue8: @sapUiChart8;
@sapUiChartPaletteQualitativeHue9: @sapUiChart9;
@sapUiChartPaletteQualitativeHue10: @sapUiChart10;
@sapUiChartPaletteQualitativeHue11: @sapUiChart11;
@sapUiChartPaletteQualitativeHue12: darken(saturate(@sapUiChartSequence1, 13), 20);
@sapUiChartPaletteQualitativeHue13: darken(saturate(@sapUiChartSequence2, 21), 17);
@sapUiChartPaletteQualitativeHue14: darken(saturate(@sapUiChartSequence3, 21), 15);
@sapUiChartPaletteQualitativeHue15: darken(saturate(@sapUiChartSequence4, 10), 17);
@sapUiChartPaletteQualitativeHue16: darken(saturate(@sapUiChartSequence5, 12), 11);
@sapUiChartPaletteQualitativeHue17: darken(saturate(@sapUiChartSequence6, 8), 12);
@sapUiChartPaletteQualitativeHue18: darken(desaturate(@sapUiChartSequence7, 18), 15);
@sapUiChartPaletteQualitativeHue19: darken(saturate(@sapUiChartSequence8, 22), 16);
@sapUiChartPaletteQualitativeHue20: darken(saturate(@sapUiChartSequence9, 16), 16);
@sapUiChartPaletteQualitativeHue21: darken(desaturate(@sapUiChartSequence10, 13), 16);
@sapUiChartPaletteQualitativeHue22: darken(saturate(@sapUiChartSequence11, 20), 10);

// semantic palette

@sapUiChartPaletteSemanticBadLight3: lighten(@sapUiChartBad, 32);
@sapUiChartPaletteSemanticBadLight2: lighten(@sapUiChartBad, 22);
@sapUiChartPaletteSemanticBadLight1: lighten(@sapUiChartBad, 12);
@sapUiChartPaletteSemanticBad: @sapUiChartBad;
@sapUiChartPaletteSemanticBadDark1: darken(desaturate(@sapUiChartBad, 1), 7);
@sapUiChartPaletteSemanticBadDark2: darken(desaturate(@sapUiChartBad, 1), 15);

@sapUiChartPaletteSemanticCriticalLight3: lighten(@sapUiChartCritical, 30);
@sapUiChartPaletteSemanticCriticalLight2: lighten(@sapUiChartCritical, 17);
@sapUiChartPaletteSemanticCriticalLight1: lighten(@sapUiChartCritical, 7);
@sapUiChartPaletteSemanticCritical: @sapUiChartCritical;
@sapUiChartPaletteSemanticCriticalDark1: darken(@sapUiChartCritical, 5);
@sapUiChartPaletteSemanticCriticalDark2: darken(@sapUiChartCritical, 12);

@sapUiChartPaletteSemanticGoodLight3: lighten(@sapUiChartGood, 30);
@sapUiChartPaletteSemanticGoodLight2: lighten(@sapUiChartGood, 17);
@sapUiChartPaletteSemanticGoodLight1: lighten(@sapUiChartGood, 7);
@sapUiChartPaletteSemanticGood: @sapUiChartGood;
@sapUiChartPaletteSemanticGoodDark1: darken(@sapUiChartGood, 7);
@sapUiChartPaletteSemanticGoodDark2: darken(@sapUiChartGood, 15);

@sapUiChartPaletteSemanticNeutralLight3: saturate(lighten(@sapUiChartNeutral, 30), 1);
@sapUiChartPaletteSemanticNeutralLight2: saturate(lighten(@sapUiChartNeutral, 20), 1);
@sapUiChartPaletteSemanticNeutralLight1: saturate(lighten(@sapUiChartNeutral, 10), 1);
@sapUiChartPaletteSemanticNeutral: @sapUiChartNeutral;
@sapUiChartPaletteSemanticNeutralDark1: saturate(darken(@sapUiChartNeutral, 10), 1);
@sapUiChartPaletteSemanticNeutralDark2: saturate(darken(@sapUiChartNeutral, 17), 1);

// sequential palette

@sapUiChartPaletteSequentialHue1Light3: lighten(saturate(@sapUiChartSequence1, 13), 23);
@sapUiChartPaletteSequentialHue1Light2: lighten(saturate(@sapUiChartSequence1, 5), 15);
@sapUiChartPaletteSequentialHue1Light1: lighten(saturate(@sapUiChartSequence1, 2), 7);
@sapUiChartPaletteSequentialHue1: @sapUiChartSequence1;
@sapUiChartPaletteSequentialHue1Dark1: darken(desaturate(@sapUiChartSequence1, 7), 11);
@sapUiChartPaletteSequentialHue1Dark2: darken(saturate(@sapUiChartSequence1, 13), 20);

@sapUiChartPaletteSequentialHue2Light3: lighten(saturate(@sapUiChartSequence2, 21), 20);
@sapUiChartPaletteSequentialHue2Light2: lighten(@sapUiChartSequence2, 21);
@sapUiChartPaletteSequentialHue2Light1: lighten(saturate(@sapUiChartSequence2, 5), 7);
@sapUiChartPaletteSequentialHue2: @sapUiChartSequence2;
@sapUiChartPaletteSequentialHue2Dark1: darken(desaturate(@sapUiChartSequence2, 1), 9);
@sapUiChartPaletteSequentialHue2Dark2: darken(saturate(@sapUiChartSequence2, 21), 17);

@sapUiChartPaletteSequentialHue3Light3: lighten(desaturate(@sapUiChartSequence3, 32), 31);
@sapUiChartPaletteSequentialHue3Light2: lighten(desaturate(@sapUiChartSequence3, 31), 20);
@sapUiChartPaletteSequentialHue3Light1: lighten(desaturate(@sapUiChartSequence3, 26), 10);
@sapUiChartPaletteSequentialHue3: @sapUiChartSequence3;
@sapUiChartPaletteSequentialHue3Dark1: darken(saturate(@sapUiChartSequence3, 8), 8);
@sapUiChartPaletteSequentialHue3Dark2: darken(saturate(@sapUiChartSequence3, 21), 15);

@sapUiChartPaletteSequentialHue4Light3: lighten(saturate(@sapUiChartSequence4, 1), 23);
@sapUiChartPaletteSequentialHue4Light2: lighten(@sapUiChartSequence4, 15);
@sapUiChartPaletteSequentialHue4Light1: lighten(@sapUiChartSequence4, 7);
@sapUiChartPaletteSequentialHue4: @sapUiChartSequence4;
@sapUiChartPaletteSequentialHue4Dark1: darken(desaturate(@sapUiChartSequence4, 5), 8);
@sapUiChartPaletteSequentialHue4Dark2: darken(saturate(@sapUiChartSequence4, 10), 17);

@sapUiChartPaletteSequentialHue5Light3: lighten(desaturate(@sapUiChartSequence5, 1), 24);
@sapUiChartPaletteSequentialHue5Light2: lighten(@sapUiChartSequence5, 16);
@sapUiChartPaletteSequentialHue5Light1: lighten(@sapUiChartSequence5, 8);
@sapUiChartPaletteSequentialHue5: @sapUiChartSequence5;
@sapUiChartPaletteSequentialHue5Dark1: darken(saturate(@sapUiChartSequence5, 4), 5);
@sapUiChartPaletteSequentialHue5Dark2: darken(saturate(@sapUiChartSequence5, 12), 11);

@sapUiChartPaletteSequentialHue6Light3: lighten(desaturate(@sapUiChartSequence6, 26), 29);
@sapUiChartPaletteSequentialHue6Light2: lighten(desaturate(@sapUiChartSequence6, 27), 19);
@sapUiChartPaletteSequentialHue6Light1: lighten(desaturate(@sapUiChartSequence6, 26), 10);
@sapUiChartPaletteSequentialHue6: @sapUiChartSequence6;
@sapUiChartPaletteSequentialHue6Dark1: darken(saturate(@sapUiChartSequence6, 4), 6);
@sapUiChartPaletteSequentialHue6Dark2: darken(saturate(@sapUiChartSequence6, 8), 12);

@sapUiChartPaletteSequentialHue7Light3: lighten(saturate(@sapUiChartSequence7, 1), 15);
@sapUiChartPaletteSequentialHue7Light2: lighten(@sapUiChartSequence7, 10);
@sapUiChartPaletteSequentialHue7Light1: lighten(saturate(@sapUiChartSequence7, 1), 5);
@sapUiChartPaletteSequentialHue7: @sapUiChartSequence7;
@sapUiChartPaletteSequentialHue7Dark1: darken(desaturate(@sapUiChartSequence7, 12), 8);
@sapUiChartPaletteSequentialHue7Dark2: darken(desaturate(@sapUiChartSequence7, 18), 15);

@sapUiChartPaletteSequentialHue8Light3: lighten(saturate(@sapUiChartSequence8, 6), 26);
@sapUiChartPaletteSequentialHue8Light2: lighten(saturate(@sapUiChartSequence8, 2), 17);
@sapUiChartPaletteSequentialHue8Light1: lighten(@sapUiChartSequence8, 9);
@sapUiChartPaletteSequentialHue8: @sapUiChartSequence8;
@sapUiChartPaletteSequentialHue8Dark1: darken(saturate(@sapUiChartSequence8, 9), 8);
@sapUiChartPaletteSequentialHue8Dark2: darken(saturate(@sapUiChartSequence8, 22), 16);

@sapUiChartPaletteSequentialHue9Light3: lighten(desaturate(@sapUiChartSequence9, 2), 34);
@sapUiChartPaletteSequentialHue9Light2: lighten(@sapUiChartSequence9, 22);
@sapUiChartPaletteSequentialHue9Light1: lighten(@sapUiChartSequence9, 11);
@sapUiChartPaletteSequentialHue9: @sapUiChartSequence9;
@sapUiChartPaletteSequentialHue9Dark1: darken(saturate(@sapUiChartSequence9, 6), 8);
@sapUiChartPaletteSequentialHue9Dark2: darken(saturate(@sapUiChartSequence9, 16), 16);

@sapUiChartPaletteSequentialHue10Light3: lighten(saturate(@sapUiChartSequence10, 9), 22);
@sapUiChartPaletteSequentialHue10Light2: lighten(saturate(@sapUiChartSequence10, 5), 14);
@sapUiChartPaletteSequentialHue10Light1: lighten(saturate(@sapUiChartSequence10, 2), 7);
@sapUiChartPaletteSequentialHue10: @sapUiChartSequence10;
@sapUiChartPaletteSequentialHue10Dark1: darken(desaturate(@sapUiChartSequence10, 8), 8);
@sapUiChartPaletteSequentialHue10Dark2: darken(desaturate(@sapUiChartSequence10, 13), 16);

@sapUiChartPaletteSequentialHue11Light3: lighten(desaturate(@sapUiChartSequence11, 24), 24);
@sapUiChartPaletteSequentialHue11Light2: lighten(desaturate(@sapUiChartSequence11, 22), 16);
@sapUiChartPaletteSequentialHue11Light1: lighten(desaturate(@sapUiChartSequence11, 17), 8);
@sapUiChartPaletteSequentialHue11: @sapUiChartSequence11;
@sapUiChartPaletteSequentialHue11Dark1: darken(saturate(@sapUiChartSequence11, 7), 4);
@sapUiChartPaletteSequentialHue11Dark2: darken(saturate(@sapUiChartSequence11, 20), 10);

@sapUiChartPaletteSequentialNeutralLight3: saturate(lighten(@sapUiChartSequenceNeutral, 30), 1);
@sapUiChartPaletteSequentialNeutralLight2: saturate(lighten(@sapUiChartSequenceNeutral, 20), 1);
@sapUiChartPaletteSequentialNeutralLight1: saturate(lighten(@sapUiChartSequenceNeutral, 10), 1);
@sapUiChartPaletteSequentialNeutral: @sapUiChartSequenceNeutral;
@sapUiChartPaletteSequentialNeutralDark1: saturate(darken(@sapUiChartSequenceNeutral, 10), 1);
@sapUiChartPaletteSequentialNeutralDark2: saturate(darken(@sapUiChartSequenceNeutral, 17), 1);

@sapUiChartPaletteNoSemDiv1Light3: #f3dec9;
@sapUiChartPaletteNoSemDiv1Light2: #e3cbb3;
@sapUiChartPaletteNoSemDiv1Light1: #c8ab8e;
@sapUiChartPaletteNoSemDiv1: #b08e6d;
@sapUiChartPaletteNoSemDiv1Dark1: #8e6c4b;
@sapUiChartPaletteNoSemDiv1Dark2: #754f2a;

@sapUiChartPaletteMidArea: desaturate(lighten(@sapUiChartSequenceNeutral, 40), 7);

@sapUiChoroplethBG: lighten(@sapUiChartSequenceNeutral, 42);
@sapUiChoroplethRegionBorder: lighten(@sapUiChartGridlineColor, 10);
@sapUiChoroplethRegionBG: @sapUiChartPaletteSemanticNeutralLight2;
@sapUiMapLegendBG: lighten(@sapUiGroupContentBackground, 2);
@sapUiMapLegendBorderColor: darken(@sapUiChartGridlineColor, 10);


// Shell
@sapUiShellContainerBackground: @sapUiGroupContentBackground;
@sapUiShellAltContainerBackground: @sapUiShellContainerBackground;
@sapUiShellGroupTextColor: @sapUiTextTitle;

@sapUiUx3ShellHeaderColor: @sapShellColor;			// "Quick"
@sapUiUx3ShellBackgroundColor: @sapUiPrimary3;
@sapUiUx3ShellHoverColor: lighten(@sapUiPrimary7, 27);
@sapUiUx3ShellGradientBottom: lighten(@sapUiUx3ShellHeaderColor, 17.3);			// transparent
@sapUiUx3ShellGradientTop: spin(mix(@sapUiHighlight, lighten(@sapUiUx3ShellGradientBottom, 22), 3), 9);			// transparent

// Approved by UX to use a hard coded color value for this
@sapUiUx3ShellToolPaletteIconFontColor: lighten(@sapUiPrimary1, 30);

// Exact
@sapUiUx3ExactLstExpandOffset: -1 -2;
@sapUiUx3ExactLstRootExpandOffset: 0 3;
@sapUiUx3ExactLstContentTop: 25px;

// Link
@sapUiLinkActive: @sapUiLinkActiveColor;
@sapUiLinkVisited: @sapUiLinkVisitedColor;
@sapUiLinkHover: @sapUiLinkHoverColor;
@sapUiLinkInverted: @sapUiLinkInvertedColor;
@sapUiLinkSubtle: @sapUiLinkSubtleColor;

// Notification Bar
@sapUiNotificationBarBG: fade(@sapUiPrimary7, 98);
@sapUiNotifierSeparator: darken(@sapUiPrimary7, 20);
@sapUiNotifierSeparatorWidth: ~"1px";
@sapUiNotificationBarBorder: lighten(@sapUiPrimary7, 20);

// ToolPopup
@sapUiUx3ToolPopupInverted: ~"false"; // Telling the ToolPopup if it's inverted per default
@sapUiUx3ToolPopupArrowRightMarginCorrection: -1px;
@sapUiUx3ToolPopupShadow: 0px 6px 12px 0px fade(@sapUiContentShadowColor, 30);

// Callout
@sapUiCalloutShadow: 0px 6px 12px 0px fade(@sapUiContentShadowColor, 30);

@sapUiButtonHeaderTextColor: @sapUiButtonTextColor;
@sapUiButtonHeaderDisabledTextColor: @sapUiButtonHeaderTextColor;
@sapUiButtonFooterTextColor: contrast(@sapUiPageFooterBackground, @sapUiButtonTextColor, @sapUiContentContrastTextColor, @sapUiContentContrastTextThreshold);
@sapUiButtonFooterHoverBackground: @sapUiButtonLiteHoverBackground;
@sapUiButtonActionSelectBackground: @sapUiListBackground;
@sapUiButtonActionSelectBorderColor: @sapUiListBorderColor;
@sapUiButtonLiteActionSelectHoverBackground: @sapUiListHoverBackground;
@sapUiToggleButtonPressedBackground: @sapUiSelected;
@sapUiToggleButtonPressedBorderColor: @sapUiToggleButtonPressedBackground;
@sapUiToggleButtonPressedTextColor: contrast(@sapUiToggleButtonPressedBackground, @sapUiButtonTextColor, @sapUiContentContrastTextColor, @sapUiContentContrastTextThreshold);
@sapUiToggleButtonPressedHoverBackground: lighten(@sapUiToggleButtonPressedBackground, 3);
@sapUiToggleButtonPressedHoverBorderColor: @sapUiToggleButtonPressedHoverBackground;
@sapUiSegmentedButtonBackground: @sapUiButtonBackground;
@sapUiSegmentedButtonBorderColor: @sapUiButtonBorderColor;
@sapUiSegmentedButtonTextColor: contrast(@sapUiSegmentedButtonBackground, @sapUiButtonTextColor, @sapUiContentContrastTextColor, @sapUiContentContrastTextThreshold);
@sapUiSegmentedButtonHoverBackground: @sapUiButtonHoverBackground;
@sapUiSegmentedButtonActiveBackground: @sapUiButtonActiveBackground;
@sapUiSegmentedButtonActiveTextColor: contrast(@sapUiSegmentedButtonActiveBackground, @sapUiSegmentedButtonTextColor, @sapUiContentContrastTextColor, @sapUiContentContrastTextThreshold);
@sapUiSegmentedButtonSelectedBackground: @sapUiToggleButtonPressedBackground;
@sapUiSegmentedButtonSelectedTextColor: @sapUiToggleButtonPressedTextColor;
@sapUiSegmentedButtonSelectedHoverBackground: @sapUiToggleButtonPressedHoverBackground;
@sapUiSegmentedButtonSelectedHoverBorderColor: @sapUiToggleButtonPressedHoverBorderColor;
@sapUiSegmentedButtonIconColor: contrast(@sapUiSegmentedButtonBackground, @sapUiContentIconColor, @sapUiContentContrastIconColor, @sapUiContentContrastTextThreshold);
@sapUiSegmentedButtonActiveIconColor: contrast(@sapUiSegmentedButtonActiveBackground, @sapUiContentIconColor, @sapUiContentContrastIconColor, @sapUiContentContrastTextThreshold);
@sapUiSegmentedButtonSelectedIconColor: contrast(@sapUiSegmentedButtonSelectedBackground, @sapUiContentIconColor, @sapUiContentContrastIconColor, @sapUiContentContrastTextThreshold);
@sapUiSegmentedButtonFooterBorderColor: @sapUiSegmentedButtonBorderColor;
@sapUiSegmentedButtonFooterHoverBackground: @sapUiSegmentedButtonHoverBackground;

@sapUiFieldActiveBackground: @sapUiActive;
@sapUiFieldActiveTextColor: @sapUiContentContrastTextColor;

@sapUiListVerticalBorderColor: @sapUiListBorderColor;
@sapUiListSelectionHoverBackground: contrast(@sapUiListSelectionBackgroundColor, darken(@sapUiListSelectionBackgroundColor, 3), lighten(@sapUiListSelectionBackgroundColor, 3));
@sapUiListTableTextSize: 0.875rem;
@sapUiListTableIconSize: 1rem;

@sapUiCalendarColorToday: @sapUiAccent4;

@sapUiDragAndDropColor: @sapUiContentNonInteractiveIconColor;
@sapUiDragAndDropBackground: @sapUiGroupContentBackground;
@sapUiDragAndDropBorderColor: @sapUiContentForegroundBorderColor;
@sapUiDragAndDropActiveColor: @sapUiActive;
@sapUiDragAndDropActiveBackground: fade(@sapUiDragAndDropActiveColor, 5);
@sapUiDragAndDropActiveBorderColor: @sapUiDragAndDropActiveColor;

@sapUiShadowLevel0: 0 0 0 0.0625rem fade(@sapUiContentShadowColor, 10), 0 0.125rem 0.5rem 0 fade(@sapUiContentShadowColor, 10);
@sapUiShadowLevel1: 0 0 0 0.0625rem fade(@sapUiContentShadowColor, 42), 0 0.125rem 0.5rem 0 fade(@sapUiContentShadowColor, 30);
@sapUiShadowLevel2: 0 0 0 0.0625rem fade(@sapUiContentShadowColor, 42), 0 0.625rem 1.875rem 0 fade(@sapUiContentShadowColor, 30);
@sapUiShadowLevel3: 0 0 0 0.0625rem fade(@sapUiContentShadowColor, 42), 0 1.25rem 5rem 0 fade(@sapUiContentShadowColor, 30);
@sapUiShadowText: none;
@sapUiShadowHeader: 0 0 0.25rem 0 fade(@sapUiContentShadowColor, 15), inset 0 -0.0625rem 0 0 @sapUiObjectHeaderBorderColor;

//images for shell
@sapUiUx3ShellHeaderImageURL: ~"";

@sapUiUx3ShellApplicationImageURL: @sapUiGlobalLogo;			// "Quick"

// DEPRECATED: Title Alignment to start (left or right) or center (default) for Dialogs, Message Boxes, Popover, Page, etc.; possible values: 'start' or 'center'
@sapMTitleAlignment: Start;
